#
# spec file for package open-vm-tools
#
# Copyright (c) 2025 SUSE LLC
# Copyright (c) 2010 Dominique Leuenberger, Amsterdam, Netherlands.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


# vgauth is enabled for openSUSE Factory, Leap 42.1, SLES12SP1 and later releases (which include xml-security-c and xerces-c)
%if 0%{?suse_version} >= 1500 || 0%{?sle_version} >= 0120100
%bcond_without vgauth
%else
%bcond_with vgauth
%endif

# vmblock-fuse.service requires systemd >= 228 which is in openSUSE Factory, SLES12SP2 and Leap 42.2 (see bsc#985773)
%if 0%{?suse_version} >= 1500 || 0%{?sle_version} >= 0120200
    %bcond_without vmblockfuseservice
%else
    %bcond_with vmblockfuseservice
%endif

# exclude AMD PCnet32 LANCE pci.id from Supplements list [bnc#397554]
%define __find_supplements sh -c '/usr/lib/rpm/find-supplements %{name} | grep -v pci:v00001022d00002000'

# X modules are lower prio upstream and once in a while fail. Offer an easy way to enable/disable them.
%define with_X 1

Name:           open-vm-tools
VCS: https://src.suse.de/ALP-pool/open-vm-tools#e2b44fdee9e7bf256a6cef95806eb430535dc82d
Version:        12.5.2
Release:        1.1
Summary:        Open Virtual Machine Tools
License:        BSD-3-Clause AND GPL-2.0-only AND LGPL-2.1-only
Group:          System/Emulators/PC
URL:            https://github.com/vmware/open-vm-tools
Source:         %{name}-%{version}.tar.gz
Source1:        vmtoolsd
Source2:        vmtoolsd.service
Source3:        vmware-user-autostart.desktop
Source5:        vmware-user-autostart-wrapper
Source6:        open-vm-tools-modprobe.conf
Source7:        tools.conf
Source8:        vgauthd.service
Source9:        vmblock-fuse.service
BuildRequires:  gcc-build-c++
# don't use pkgconfig(gtk+-2.0) so we can build on SLE
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  doxygen
BuildRequires:  gtk3-devel
BuildRequires:  gtkmm3-devel
BuildRequires:  libdnet-devel
BuildRequires:  libicu-devel
BuildRequires:  libmspack-devel
BuildRequires:  libtool
BuildRequires:  openssl-devel
BuildRequires:  pam-devel
BuildRequires:  procps-devel
BuildRequires:  update-desktop-files
%if 0%{?suse_version} > 1500 || 0%{?sle_version} >= 150300
BuildRequires:  containerd-devel
BuildRequires:  grpc-devel
BuildRequires:  libcurl-devel
BuildRequires:  protobuf-devel
%define         arg_containerinfo --enable-containerinfo=yes
%else
%define         arg_containerinfo --enable-containerinfo=no
%endif
%if 0%{?suse_version} > 1500 || 0%{?sle_version} >= 150300
BuildRequires:  glibc >= 2.27
BuildRequires:  libtirpc-devel
BuildRequires:  rpcgen
BuildRequires:  pkgconfig(sm)
BuildRequires:  pkgconfig(xcomposite)
BuildRequires:  pkgconfig(xext)
BuildRequires:  pkgconfig(xi)
BuildRequires:  pkgconfig(xinerama)
BuildRequires:  pkgconfig(xrandr)
BuildRequires:  pkgconfig(xrender)
BuildRequires:  pkgconfig(xtst)
%else
BuildRequires:  glibc >= 2.12
BuildRequires:  xorg-x11-devel
%endif
BuildRequires:  pkgconfig(libdrm)
BuildRequires:  pkgconfig(libudev)
%if %{with vgauth}
# vgauth requires xmlsec1 + libxml2 - or - xerces-c + xml-security-c
# The preferred combination is xmlsec1 and libxml2

# Use xmlsec1 instead of xml-security-c where available.
# If using xmlsec1, also need to use libxmlsec1-openssl1
%if 0%{?suse_version} > 1500 || 0%{?sle_version} >= 0120300
BuildRequires:  libxml2-devel
BuildRequires:  pkgconfig(xmlsec1)
%if 0%{?suse_version} > 1500 || 0%{?sle_version} >= 0150400
Requires:       libxmlsec1-openssl1 >= 1.2.37
%else
%if 0%{?sle_version} == 0120400 || 0%{?sle_version} == 0120500
Requires:       libxmlsec1-openssl1 >= 1.2.37
%else
Requires:       libxmlsec1-openssl1 >= 1.2.28
%endif
%endif
%define         arg_xmlsec1 --enable-xmlsec1
%else
# Leap 42.1 and 42.2 supports xmlsec1 and libxmlsec1-openssl1 but 12 SP1 and
# SP2 do not.
%if 0%{?is_opensuse} && 0%{?sle_version} >= 0120100
BuildRequires:  libxml2-devel
BuildRequires:  pkgconfig(xmlsec1)
Requires:       libxmlsec1-openssl1
%define         arg_xmlsec1 --enable-xmlsec1
%else
BuildRequires:  xml-security-c-devel
BuildRequires:  pkgconfig(xerces-c)
%define         arg_xmlsecurity --enable-xmlsecurity
%endif
%endif

%else
# not using vgauth
%define arg_xmlsecurity --without-xmlsecurity
%define arg_xerces --without-xerces
%endif
# vmhgfs is always built so fuse is no longer optional
%if 0%{?suse_version} > 1500 || 0%{?sle_version} >= 0150400
BuildRequires:  fuse3-devel
%define         arg_with_fuse --with-fuse=3
%else
BuildRequires:  fuse-devel
%define         arg_with_fuse --with-fuse=2
%endif
BuildRequires:  pkgconfig(udev)
%if 0%( pkg-config --exists 'udev > 190' && echo '1' ) == 01
%define _udevrulesdir /usr/lib/udev/rules.d
%else
%define _udevrulesdir /lib/udev/rules.d
%endif
Requires:       libvmtools0 = %{version}-%{release}
Requires:       net-tools
Requires:       tar
Requires:       which
# open-vm-tools >= 10.0.0 do not require open-vm-tools-deploypkg
# provided by VMware. That functionality is now available as part
# of open-vm-tools package itself.
Obsoletes:      open-vm-tools-deploypkg <= 10.0.5
Supplements:    modalias(pci:v000015ADd*sv*sd*bc*sc*i*)
ExclusiveArch:  %ix86 x86_64 aarch64
#Upstream patches
Patch42:        open-vm-tools-12.5.0-gcc15.patch

#SUSE specific patches
Patch0:         pam-vmtoolsd.patch
Patch1:         detect-suse-location.patch

%if 0%{?suse_version} >= 1500
%systemd_ordering
%else
%systemd_requires
%endif

%description
Open Virtual Machine Tools (open-vm-tools) are the open source
implementation of VMware Tools. They are a set of guest operating
system virtualization components that enhance performance and user
experience of virtual machines. As virtualization technology rapidly
becomes mainstream, each virtualization solution provider implements
their own set of tools and utilities to supplement the guest virtual
machine. However, most of the implementations are proprietary and are
tied to a specific virtualization platform.

With the Open Virtual Machine Tools project, we are hoping to solve
this and other related problems. The tools are currently composed of
kernel modules for Linux and user-space programs for all VMware
supported Unix-like guest operating systems. They provide several
useful functions like:

* File transfer between a host and guest

* Improved memory management and network performance under
   virtualization

* General mechanisms and protocols for communication between host and
guests and from guest to guest

%if %{with_X}

%package        desktop
Summary:        User experience components for Open Virtual Machine Tools
Group:          System/Emulators/PC
Requires:       %{name}%{?_isa} = %{version}-%{release}
Obsoletes:      %{name}-gui < %{version}
Provides:       %{name}-gui = %{version}
Supplements:    packageand(open-vm-tools:xorg-x11-server)
Requires(pre):  permissions

%description    desktop
This package contains only the user-space programs and libraries of
%{name} that are essential for improved user experience of VMware virtual
machines.
%endif

%package        sdmp
Summary:        Service Discovery Plugin
Group:          System Environment/Libraries
Requires:       %{name}%{?_isa} = %{version}-%{release}

%description      sdmp
Service Discovery Plugin

%package        salt-minion
Summary:        Script file to install/uninstall salt-minion
Group:          System Environment/Libraries
Requires:       %{name}%{?_isa} = %{version}-%{release}, systemd, curl, coreutils, gawk, grep
ExclusiveArch:  x86_64

%description    salt-minion
This package contains a script to setup Salt Minion on VMware virtual machines.

%package -n libvmtools0
Summary:        Open Virtual Machine Tools - shared library
Group:          System/Libraries

%description -n libvmtools0
This is a shared library used by several Open VM Tools components,
such as vmware-toolbox-cmd and vmtoolsd (and its plugins).

%package -n libvmtools-devel
Summary:        Open Virtual Machine Tools - Development headers
Group:          Development/Libraries/C and C++
Requires:       libvmtools0 = %{version}

%description -n libvmtools-devel
Those are the development headers for libvmtools. They are needed
if you intend to create own plugins for vmtoolsd.

%if 0%{?suse_version} > 1500 || 0%{?sle_version} >= 150300
%package        containerinfo
Summary:        Container Info Plugin
Group:          System Environment/Libraries
Requires:       %{name}%{?_isa} = %{version}-%{release}, curl

%description    containerinfo
This package interfaces with the container runtime to retrieve a list of containers running on a Linux guest
%endif

%prep
%setup -q -n %{name}-%{version}/%{name}

# fix for an rpmlint warning regarding wrong line feeds
sed -i -e "s/\r//" README
#Upstream patches
%patch -P 42 -p2

#SUSE specific patches
%patch -P 0 -p2
%patch -P 1 -p2

%build
autoreconf -fi
%if %{with_X}
    %define arg_x --with-x
%else
    %define arg_x --without-x
%endif

# disable warning unused-but-set-variable which will raise error because of -Werror
# disable warning deprecated-declarations which will raise error because of -Werror
# disable warning sizeof-pointer-memaccess which will raise error because of -Werror
# (this is because of 'g_static_mutex_init' usage which is now deprecated)
export CFLAGS="%{optflags} -Wno-unused-local-typedefs -Wno-unused-but-set-variable -Wno-deprecated-declarations -Wno-sizeof-pointer-memaccess -Wno-cpp -fPIE"
export CXXFLAGS="%{optflags} -Wno-unused-local-typedefs -Wno-unused-but-set-variable -Wno-deprecated-declarations -Wno-sizeof-pointer-memaccess -Wno-cpp -fPIE"
%if 0%{?suse_version} > 1500 || 0%{?sle_version} >= 150400
export LDFLAGS="-pie -ltirpc -lgrpc -labsl_synchronization -labsl_log_internal_check_op -labsl_log_internal_nullguard -labsl_log_internal_message"
%else
%if 0%{?sle_version} >= 150300
export LDFLAGS="-pie -ltirpc"
%else
export LDFLAGS="-pie"
%endif
%endif
# Required for version 9.4.0
export CUSTOM_PROCPS_NAME=procps
autoreconf -fi
echo 'HTML_TIMESTAMP=NO' >> docs/api/doxygen.conf
# In the latest official tarballs, configure is not marked executable
chmod 755 configure
%configure \
    --without-kernel-modules \
    --without-root-privileges \
    %{?arg_x} \
    --disable-dependency-tracking \
    --with-gtk3 \
    %{?arg_xmlsec1} \
    %{?arg_xmlsecurity} \
    %{?arg_xerces} \
    --with-udev-rules-dir=%{_udevrulesdir} \
    --enable-resolutionkms \
    --enable-servicediscovery \
    %{arg_with_fuse} \
    --enable-salt-minion \
    --disable-static \
    %{?arg_containerinfo}
make

%install
%make_install

%if 0%{?suse_version} > 1500 || 0%{?sle_version} >= 150300
mkdir -p  %buildroot%_modulesloaddir
echo vmw_vsock_vmci_transport > %buildroot%_modulesloaddir/vmw_vsock_vmci_transport.conf
%endif
mkdir -p  %{buildroot}%{_sbindir}

# Remove exec bit from config files
chmod a-x %{buildroot}%{_sysconfdir}/pam.d/*
%if 0%{?suse_version} > 1500
install -d %{buildroot}%{_pam_vendordir}
mv %{buildroot}%{_sysconfdir}/pam.d/vmtoolsd %{buildroot}%{_pam_vendordir}
%endif

# Remove unnecessary files from packaging
find %{buildroot}%{_libdir} -name '*.la' -delete
rm -fr %{buildroot}%{_defaultdocdir}
rm -fr %{buildroot}/usr/share/doc/open-vm-tools/api
rm -f docs/api/build/html/FreeSans.ttf

# install systemd init scripts and symlinks
install -p -m 644 -D %{SOURCE2} %{buildroot}%{_unitdir}/vmtoolsd.service
ln -sf service %{buildroot}%{_sbindir}/rcvmtoolsd
%if %{with vmblockfuseservice}
install -p -m 644 -D %{SOURCE9} %{buildroot}%{_unitdir}/vmblock-fuse.service
ln -sf service %{buildroot}%{_sbindir}/rcvmblock-fuse
%endif
%if %{with vgauth}
install -p -m 644 -D %{SOURCE8} %{buildroot}%{_unitdir}/vgauthd.service
ln -sf service %{buildroot}%{_sbindir}/rcvgauthd
mkdir -p %{buildroot}%{_var}/lib/vmware
%else
# if vgauth is not enabled, it must be removed from vmtoolsd.service
sed -i '/vgauth/d' %{buildroot}%{_unitdir}/vmtoolsd.service
%endif

%if %{with_X}
# vmware-user is started by vmware-user-suid-wrapper by xdg-autostart
# unfortunately, vmware-user-suid-wrapper does not wait for it's block device
# to appear. For this reason we have now a vmware-user-autostart-wrapper
# which checks for /proc/fs/vmblock/dev to appear and then starts vmware-user-suid-wrapper
install -D -m 0755 %{SOURCE5} %{buildroot}%{_bindir}/vmware-user-autostart-wrapper
install -D -m 0644 %{SOURCE3} %{buildroot}%{_sysconfdir}/xdg/autostart/vmware-user-autostart.desktop

# Install the default tools.conf
install -D -m 0644 %{S:7} %{buildroot}%{_sysconfdir}/vmware-tools/tools.conf
# Remove the 'disable-perl-mon=1' setting if procps is available
sed -i '/openSUSE/,+2d' %{buildroot}%{_sysconfdir}/vmware-tools/tools.conf

# We have our own 'safe' autostart wrapper, which checks for modules to start in autologin mode...
# Thus we drop the 'original' autostartup
rm %{buildroot}%{_sysconfdir}/xdg/autostart/vmware-user.desktop

# handle the .destop files for translations
%suse_update_desktop_file vmware-user-autostart
%endif

# modprobe configuration for vmnics - only include if before SLE-12
%if 0%{?suse_version} < 1315
install -D -m 0644 %{SOURCE6} %{buildroot}%{_sysconfdir}/modprobe.d/50-vmnics.conf
%endif

%pre
%service_add_pre vmtoolsd.service
%service_add_pre vgauthd.service
%if 0%{?suse_version} > 1500
# Prepare for migration to /usr/etc; save any old .rpmsave
for i in pam.d/vmtoolsd ; do
     test -f %{_sysconfdir}/${i}.rpmsave && mv -v %{_sysconfdir}/${i}.rpmsave %{_sysconfdir}/${i}.rpmsave.old ||:
done

%posttrans
# Migration to /usr/etc, restore just created .rpmsave
for i in pam.d/vmtoolsd ; do
     test -f %{_sysconfdir}/${i}.rpmsave && mv -v %{_sysconfdir}/${i}.rpmsave %{_sysconfdir}/${i} ||:
done
%endif

%post
/sbin/ldconfig
%service_add_post vmtoolsd.service vgauthd.service vmblock-fuse.service

%if %{with_X}

%verifyscript desktop
%verify_permissions -e /usr/bin/vmware-user-suid-wrapper

%if %{with vmblockfuseservice}
%pre desktop
%service_add_pre vmblock-fuse.service
%endif

%post desktop
%set_permissions /usr/bin/vmware-user-suid-wrapper
%if %{with vmblockfuseservice}
%service_add_post vmblock-fuse.service
%endif
/sbin/ldconfig

%preun desktop
%if %{with vmblockfuseservice}
%service_del_preun vmblock-fuse.service
%endif

%postun desktop
%if %{with vmblockfuseservice}
%service_del_postun vmblock-fuse.service
%endif
/sbin/ldconfig

%endif

%post sdmp
systemctl try-restart vmtoolsd.service || :

%preun
%service_del_preun vmtoolsd.service
%if %{with vgauth}
%service_del_preun vgauthd.service
%endif
# Tell VMware that open-vm-tools is being uninstalled
if [ "$1" = "0" -a \
 -e %{_bindir}/vmware-checkvm -a \
 -e %{_bindir}/vmware-rpctool ] && \
 %{_bindir}/vmware-checkvm > /dev/null 2>&1; then
 %{_bindir}/vmware-rpctool 'tools.set.version 0' > /dev/null 2>&1 || true
fi

%postun
%service_del_postun vmtoolsd.service
%if %{with vgauth}
%service_del_postun vgauthd.service
%endif
/sbin/ldconfig

%postun sdmp
# restart tools without plugin
systemctl try-restart vmtoolsd.service || :

%post -n libvmtools0 -p /sbin/ldconfig

%postun -n libvmtools0 -p /sbin/ldconfig

%if 0%{?suse_version} > 1500 || 0%{?sle_version} >= 150300
%post containerinfo
systemctl try-restart vmtoolsd.service || :

%postun containerinfo
systemctl try-restart vmtoolsd.service || :
%endif

%files
%if 0%{?suse_version} > 1500 || 0%{?sle_version} >= 150300
%dir %_modulesloaddir
%_modulesloaddir/vmw_vsock_vmci_transport.conf
%endif
%if 0%{?suse_version} > 1500 || 0%{?sle_version} >= 0120300
%license COPYING
%doc AUTHORS ChangeLog NEWS README
%else
%doc AUTHORS COPYING ChangeLog NEWS README
%endif

%{_bindir}/vmtoolsd
%dir %{_libdir}/%{name}
%dir %{_libdir}/%{name}/plugins
%dir %{_libdir}/%{name}/plugins/common
%dir %{_libdir}/%{name}/plugins/vmsvc
%{_libdir}/%{name}/plugins/vmsvc/libdeployPkgPlugin.so
%{_libdir}/%{name}/plugins/vmsvc/libguestInfo.so
%{_libdir}/%{name}/plugins/vmsvc/libpowerOps.so
%{_libdir}/%{name}/plugins/vmsvc/libresolutionKMS.so
%{_libdir}/%{name}/plugins/vmsvc/libtimeSync.so
%{_libdir}/%{name}/plugins/vmsvc/libvmbackup.so
%{_libdir}/%{name}/plugins/vmsvc/libappInfo.so
%{_libdir}/%{name}/plugins/vmsvc/libgdp.so
%{_libdir}/%{name}/plugins/vmsvc/libguestStore.so
%{_libdir}/%{name}/plugins/vmsvc/libcomponentMgr.so
%{_libdir}/%{name}/plugins/common/libhgfsServer.so
%{_libdir}/%{name}/plugins/common/libvix.so
%{_bindir}/vmhgfs-fuse
%{_bindir}/vmware-checkvm
%{_bindir}/vmware-hgfsclient
%{_bindir}/vmware-namespace-cmd
%{_bindir}/vmware-rpctool
%{_bindir}/vmware-toolbox-cmd
%{_bindir}/vmware-xferlogs
%{_bindir}/vm-support
%{_bindir}/vmware-alias-import
%if 0%{?suse_version} > 1500
%{_pam_vendordir}/vmtoolsd
%else
%config(noreplace) %{_sysconfdir}/pam.d/vmtoolsd
%endif
%dir %{_sysconfdir}/vmware-tools
%dir %{_sysconfdir}/vmware-tools/scripts
%dir %{_sysconfdir}/vmware-tools/scripts/vmware
%{_sysconfdir}/vmware-tools/poweroff-vm-default
%{_sysconfdir}/vmware-tools/poweron-vm-default
%{_sysconfdir}/vmware-tools/resume-vm-default
%{_sysconfdir}/vmware-tools/scripts/vmware/network
%{_sysconfdir}/vmware-tools/statechange.subr
%{_sysconfdir}/vmware-tools/suspend-vm-default
%{_udevrulesdir}/99-vmware-scsi-udev.rules
%config(noreplace) %{_sysconfdir}/vmware-tools/tools.conf
%config(noreplace) %{_sysconfdir}/vmware-tools/tools.conf.example
%if 0%{?suse_version} < 1315
%dir %{_sysconfdir}/modprobe.d
%config %{_sysconfdir}/modprobe.d/50-vmnics.conf
%endif
%if %{with vgauth}
%dir %{_var}/lib/vmware
%{_bindir}/VGAuthService
%{_bindir}/vmware-vgauth-cmd
%{_bindir}/vmware-vgauth-smoketest
%dir %{_sysconfdir}/vmware-tools/vgauth
%dir %{_sysconfdir}/vmware-tools/vgauth/schemas
%config(noreplace) %{_sysconfdir}/vmware-tools/vgauth.conf
%config(noreplace) %{_sysconfdir}/vmware-tools/vgauth/schemas/*
%endif
%{_datadir}/%{name}/
%{_unitdir}/vmtoolsd.service
%if %{with vgauth}
%{_unitdir}/vgauthd.service
%{_sbindir}/rcvgauthd
%endif
%{_sbindir}/rcvmtoolsd
%exclude %{_libdir}/*.so

%if %{with_X}

%files desktop
%config %{_sysconfdir}/xdg/autostart/vmware-user-autostart.desktop
%verify(not mode) %attr(0755, root, root) %{_bindir}/vmware-user-suid-wrapper
%{_libdir}/%{name}/plugins/vmusr/
%{_bindir}/vmware-user
%{_bindir}/vmware-user-autostart-wrapper
%{_bindir}/vmware-vmblock-fuse
%{_bindir}/vmwgfxctrl
%if %{with vmblockfuseservice}
%{_unitdir}/vmblock-fuse.service
%{_sbindir}/rcvmblock-fuse
%endif

%endif

%ifarch x86_64
%files salt-minion
%dir %{_libdir}/%{name}/componentMgr/
%dir %{_libdir}/%{name}/componentMgr/saltMinion/
%{_libdir}/%{name}/componentMgr/saltMinion/svtminion.sh
%endif

%files sdmp
%dir %{_libdir}/%{name}/serviceDiscovery/
%dir %{_libdir}/%{name}/serviceDiscovery/scripts/
%{_libdir}/%{name}/plugins/vmsvc/libserviceDiscovery.so
%{_libdir}/%{name}/serviceDiscovery/scripts/get-connection-info.sh
%{_libdir}/%{name}/serviceDiscovery/scripts/get-listening-process-info.sh
%{_libdir}/%{name}/serviceDiscovery/scripts/get-listening-process-perf-metrics.sh
%{_libdir}/%{name}/serviceDiscovery/scripts/get-versions.sh

%files -n libvmtools0
%{_libdir}/libvmtools.so.*
%{_libdir}/libguestlib.so.*
%{_libdir}/libhgfs.so.*
%{_libdir}/libDeployPkg.so.*
%{_libdir}/libguestStoreClient.so.*
%if %{with vgauth}
%{_libdir}/libvgauth.so.*
%endif

%files -n libvmtools-devel
%doc docs/api/build/*
%{_includedir}/vmGuestLib
%{_libdir}/*.so
%{_libdir}/pkgconfig/vmguestlib.pc
%{_includedir}/libDeployPkg
%{_libdir}/pkgconfig/libDeployPkg.pc

%if 0%{?suse_version} > 1500 || 0%{?sle_version} >= 150300
%files containerinfo
%{_libdir}/%{name}/plugins/vmsvc/libcontainerInfo.so
%endif

%changelog
* Tue May 13 2025 opensuse_buildservice@ojkastl.de
- update to 12.5.2 (bsc#1243106):
  https://github.com/vmware/open-vm-tools/blob/stable-12.5.2/ReleaseNotes.md
  https://github.com/vmware/open-vm-tools/blob/stable-12.5.2/open-vm-tools/ChangeLog
  This release resolves CVE-2025-22247. For more information on this
  vulnerability and its impact on Broadcom products, see
  VMSA-2025-0007
  https://support.broadcom.com/web/ecx/support-content-notification/-/external/content/SecurityAdvisories/0/25683
* Sat May  3 2025 hsk17@mail.de
- Add open-vm-tools-12.5.0-gcc15.patch from upstream to fix
  gcc15 compile time error (boo#1241938)
* Wed Apr 16 2025 kallan@suse.com
- (bsc#1237147): Newer version of containerd do not have the directory
  /usr/share/go/1.x/contrib/src/github.com/containerd/containerd/api.
  Update detect-suse-location.patch to point to the directory
  /usr/share/go/1.x/contrib/src/github.com/containerd/containerd/vendor/github.com/containerd/containerd/api
  to find the needed files and update the tasks.proto file to import from
  github.com/containerd/containerd/vendor/github.com/containerd/containerd/api
* Thu Mar 27 2025 kallan@suse.com
- (bsc#1237180): Ensure vmtoolsd.service and vgauthd.service
  are set to enabled by default. Do this by removing vmblock-fuse.service
  from the %%pre section in the spec file.  vmblock-fuse.service still
  remains in the %%pre desktop section.
* Thu Mar 20 2025 andreas.stieger@gmx.de
- remove unused pcre build dependency
* Tue Feb 25 2025 kallan@suse.com
- Revert previous change (Thu Feb 20 23:08:43 UTC 2025).  The proposed
  solutions was non-standard.
* Thu Feb 20 2025 kallan@suse.com
- (bsc#1237180): Ensure vmtoolsd.service, vgauthd.service, and
  vmblock-fuse.service are set to enabled by default.
* Fri Oct 11 2024 opensuse_buildservice@ojkastl.de
- convert to obs_scm
- update to 12.5.0 (boo#1231826):
  There are no new features in the open-vm-tools 12.5.0 release.
  This is primarily a maintenance release that addresses a few
  critical problems, including:
  * A Github pull request has been integrated. Please see the
    Resolved Issues section of the Release Notes.
  * For a more complete list of issues resolved in this release,
    see the Resolved Issues section of the Release Notes.
  For complete details, see:
  https://github.com/vmware/open-vm-tools/releases/tag/stable-12.5.0
  Release Notes are available at:
  https://github.com/vmware/open-vm-tools/blob/stable-12.5.0/ReleaseNotes.md
  The granular changes that have gone into the 12.5.0 release are
  in the ChangeLog at:
  https://github.com/vmware/open-vm-tools/blob/stable-12.5.0/open-vm-tools/ChangeLog
* Mon Jul  1 2024 kallan@suse.com
- Update to 12.4.5 (build 23787635) (boo#1227181)
  - There are no new features in the open-vm-tools 12.4.5 release. This is
    primarily a maintenance release that addresses a few critical problems,
    including:
  - A Github pull request and associated issue has been handled. Please
    see the Resolved Issues section of the Release Notes.
  - A number of issues flagged by Coverity and ShellCheck have been
    addressed.
  - A vmtoolsd process hang related to nested logging from an RPC Channel
    error has been fixed.
  For a more complete list of issues resolved in this release, see the
  Resolved Issues section of the Release Notes.
  For complete details, see: https://github.com/vmware/open-vm-tools/releases/tag/stable-12.4.5
  Release Notes are available at: https://github.com/vmware/open-vm-tools/blob/stable-12.4.5/ReleaseNotes.md
  The granular changes that have gone into the 12.4.5 release are in the ChangeLog at: https://github.com/vmware/open-vm-tools/blob/stable-12.4.5/open-vm-tools/ChangeLog
* Wed Mar 27 2024 kallan@suse.com
- Remove protobuf < 22 dependency from spec file (bsc#1217478)
  Required linking with additional absl libraries for sle_version > 150400.
- Use (boo#1222089) for updating open-vm-tools to version 12.4.0.
* Sat Mar 23 2024 opensuse_buildservice@ojkastl.de
- update to 12.4.0:
  https://github.com/vmware/open-vm-tools/blob/stable-12.4.0/ReleaseNotes.md
  https://github.com/vmware/open-vm-tools/blob/stable-12.4.0/open-vm-tools/ChangeLog
  There are no new features in the open-vm-tools 12.4.0 release.
  This is primarily a maintenance release that addresses a few
  critical problems, including:
  * A Github pull request has been handled. Please see the Resolved
    Issues section of the Release Notes.
  * A number of issues flagged by Coverity have been addressed.
  * For issues resolved in this release, see the Resolved Issues
    section of the Release Notes.
* Mon Feb 26 2024 dimstar@opensuse.org
- Use %%patch -P N instead of deprecated %%patchN.
* Wed Dec 20 2023 dimstar@opensuse.org
- Own %%{_modulesloaddir}: used to be present via udev-mini -> kmod
  - > suse-module-tools dependency before.
* Mon Dec 11 2023 kallan@suse.com
- Fix (bsc#1217796) - Fix outdated libxmlsec1 dependency version.
  Updates to open-vm-tools for SLES 12 SP4 and SP5 are now being built
  againt against libxmlsec1-1-1.2.37. Update the spec file to now require
  libxmlsec1-openssl1 >= 1.2.37.
* Mon Oct 30 2023 kallan@suse.com
- Update to 12.3.5 (build 22544099) (boo#1216670)
  - There are no new features in the open-vm-tools 12.3.5 release. This is
    primarily a maintenance release that addresses a few critical problems,
    including:
  - This release resolves CVE-2023-34058. For more information on this
    vulnerability and its impact on VMware products, see
    https://www.vmware.com/security/advisories/VMSA-2023-0024.html.
  - This release resolves CVE-2023-34059 which only affects open-vm-tools.
    For more information on this vulnerability, please see the Resolved
    Issues section of the Release Notes.
  - A GitHub issue has been handled. Please see the Resolved Issues section
    of the Release Notes.
  - An update to the deployPkg plugin to coordinate with recent releases
    of cloud-init for improvement for guest VM customization.
  - For issues resolved in this release, see the Resolved Issues
    <https://github.com/vmware/open-vm-tools/blob/stable-12.3.5/ReleaseNotes.md#resolved-issues>
    section of the Release Notes.
  - For complete details, see:
    https://github.com/vmware/open-vm-tools/releases/tag/stable-12.3.5
  - Release Notes are available at
    https://github.com/vmware/open-vm-tools/blob/stable-12.3.5/ReleaseNotes.md
  - The granular changes that have gone into the 12.3.5 release are in the
    ChangeLog at
    https://github.com/vmware/open-vm-tools/blob/stable-12.3.5/open-vm-tools/ChangeLog
- Drop patch now contained in 12.3.5:
  - CVE-2023-34058.patch
  - CVE-2023-34059.patch
* Sun Oct 22 2023 bjorn.lie@gmail.com
- Drop pkgconfig(gdk-pixbuf-xlib-2.0) BuildRequires: No longer
  needed, nor used (since 12.3.0 release).
* Fri Oct 20 2023 kallan@suse.com
- Fix (bsc#1216432) - VUL-0: CVE-2023-34058: open-vm-tools: SAML token
  signature bypass vulnerability.
- Fix (bsc#1216433) - VUL-0: : CVE-2023-34059: open-vm-tools: file
  descriptor hijack vulnerability
  + Add patch:
  - CVE-2023-34058.patch
  - CVE-2023-34059.patch
* Thu Sep 28 2023 kallan@suse.com
- 15 sp4 currently uses open-vm-tools rpms from 15 sp3.  As such, enable
  the spec file fix for bug (bsc#1205927) for 15 sp3 onwards.
* Thu Sep 21 2023 meissner@suse.com
- open-vm-tools is built with containerinfo plugin from 15 sp3 onwards
* Wed Sep  6 2023 kallan@suse.com
- Update to 12.3.0 (build 22234872) (boo#1214850)
  - There are no new features in the open-vm-tools 12.3.0 release. This is
    primarily a maintenance release that addresses a few critical problems,
    including:
  - This release integrates CVE-2023-20900 without the need for a patch.
    For more information on this vulnerability and its impact on VMware
    products, see
    https://www.vmware.com/security/advisories/VMSA-2023-0019.html.
  - A tools.conf configuration setting is available to temporaily direct
    Linux quiesced snaphots to restore pre open-vm-tools 12.2.0 behavior
    of ignoring file systems already frozen.
  - Building of the VMware Guest Authentication Service (VGAuth) using
    "xml-security-c" and "xerces-c" is being deprecated.
  - A number of Coverity reported issues have been addressed.
  - A number of GitHub issues and pull requests have been handled.
    Please see the Resolves Issues section of the Release Notes.
  - For issues resolved in this release, see the Resolved Issues section
    of the Release Notes.
  - For complete details, see:
    https://github.com/vmware/open-vm-tools/releases/tag/stable-12.3.0
  - Release Notes are available at
    https://github.com/vmware/open-vm-tools/blob/stable-12.3.0/ReleaseNotes.md
  - The granular changes that have gone into the 12.3.0 release are in the
    ChangeLog at
    https://github.com/vmware/open-vm-tools/blob/stable-12.3.0/open-vm-tools/ChangeLog
- Fix (bsc#1205927) - hv_vmbus module is loaded unnecessarily in VMware guests
- jsc-PED-1344 - reinable building containerinfo plugin for SLES 15 SP4.
- Drop patch now contained in 12.3.0:
  + 0001-build-put-l-specifiers-into-LIBADD-not-LDFLAGS.patch
  + 0002-build-use-grpc-pkgconfig-to-retrieve-flags-libraries.patch
  + 2023-20867-Remove-some-dead-code.patch
  + CVE-20230-20900.patch
* Mon Aug 28 2023 kallan@suse.com
- Fix (bsc#1214566) - (CVE-2023-20900) - VUL-0: CVE-2023-20900:
  open-vm-tools: SAML token signature bypass vulnerability
  + Add patch: CVE-20230-20900.patch
* Tue Jun 27 2023 dmueller@suse.com
- limit to protobuf < 22 for now until build failures have been fixed
* Mon Jun 12 2023 kallan@suse.com
- Fix (bsc#1212143) - (CVE-2023-20867) - VUL-0: CVE-2023-20867:
  open-vm-tools: Authentication Bypass vulnerability in the vgauth
  module
  + Add patch: 2023-20867-Remove-some-dead-code.patch
* Tue May  2 2023 jengelh@inai.de
- Add 0001-build-put-l-specifiers-into-LIBADD-not-LDFLAGS.patch,
  0002-build-use-grpc-pkgconfig-to-retrieve-flags-libraries.patch
  [boo#1210695]
- Reduce generated script size by coalescing multiple %%service_*
* Tue Apr  4 2023 kallan@suse.com
- As per jsc-PED-1344, update spec file to only build the containerinfo
  plugin for TW/SLES 15 SP5 and newer.
* Tue Mar 28 2023 kallan@suse.com
- Update to 12.2.0 (build 21223074) (boo#1209128)
  - There are no new features in the open-vm-tools 12.2.0 release. This is
    primarily a maintenance release that addresses a few critical problems,
    including:
  - Linux quiesced snapshots have been updated to avoid intermittent hangs of
    the vmtoolsd process.
  - Updated the guestOps to handle some edge cases when File_GetSize() fails
    or returns -1.
  - A number of Coverity reported issues have been addressed.
  - Detect the proto files for the containerd grpc client in alternate
    locations.  Pull request #626
  - FreeBSD: Support newer releases and code clean-up for earlier versions.
    Pull request #584
  - Please refer to the release notes at
    https://github.com/vmware/open-vm-tools/blob/stable-12.2.0/ReleaseNotes.md
  - The granular changes that have gone into the 12.2.0 release are in the
    ChangeLog at https://github.com/vmware/open-vm-tools/blob/stable-12.2.0/
    open-vm-tools/ChangeLog
- Update detect-suse-location.patch to remove upstream accepted portion of the
  patch (jsc-PED-1344).
* Wed Dec 28 2022 schubi@suse.com
- Migration of PAM settings to /usr/lib/pam.d.
* Wed Dec 14 2022 kallan@suse.com
- Don't list libgrpc++, libgrpc, and libprotobuf in the containerinfo Requires
  section.  The dependencies will be added automatically.
* Tue Dec 13 2022 kallan@suse.com
- Don't use new LDFLAGS, -labsl_synchronization -lgpr, when building for SLE.
* Mon Dec 12 2022 caleb.crane@suse.com
- Add containerInfo plugin (jsc-PED-1344)
  - Add dependencies on grpc, protobuf, and containerd for container
    introspection
- Added patches (jsc-PED-1344)
  + detect-suse-location.patch
* Thu Dec  8 2022 caleb.crane@suse.com
- Add _service to handle open-vm-tools sources
- Update to 12.1.5 (build 20735119) (boo#1205962)
  - A number of Coverity reported issues have been addressed.
  - The deployPkg plugin may prematurely reboot the guest VM before cloud-init
    has completed user data setup. If both the Perl based Linux customization
    script and cloud-init run when the guest VM boots, the deployPkg plugin
    may reboot the guest before cloud-init has finished. The deployPkg
    plugin has been updated to wait for a running cloud-init process to
    finish before the guest VM reboot is initiated. This issue is fixed in
    this release.
  - A SIGSEGV may be encountered when a non-quiesing snapshot times out.
    This issue is fixed in this release.
  - Unwanted vmtoolsd service error message if not on a VMware hypervisor.
    When open-vm-tools comes preinstalled in a base Linux release, the vmtoolsd
    services are started automatically at system start and desktop login.
    If running on physical hardware or in a non-VMware hypervisor, the services
    will emit an error message to the Systemd's logging service before stopping.
    This issue is fixed in this release.
* Thu Aug 25 2022 kallan@suse.com
- Update to 12.1.0 (build 20219665) (boo#1202733)
  + New/Updated features:
  - Contains security update fix for (bsc#1202657) - (CVE-2022-31676)
    VUL-0: CVE-2022-31676: open-vm-tools:
    local privilege escalation vulnerability
  + A number of Coverity reported issues have been addressed.
  + [FTBFS] Fix the build of the ContainerInfo plugin for a 32-bit Linux
    release:
    https://github.com/vmware/open-vm-tools/pull/588
  + Make HgfsConvertFromNtTimeNsec aware of 64-bit time_t on i386 (32-bit)
    This change incorporates the support of 64 bit time epoch conversion
    from Windows NT time to Unix Epoch time on i386.
    https://github.com/vmware/open-vm-tools/pull/387
- Drop patch now contained in 12.1.0:
  + gcc_size_t.patch
* Mon Mar 28 2022 kallan@suse.com
- Update to 12.0.0 (build 19345655) (boo#1196803)
- jsc#SLE-24097 ECO Update open-vm-tools 12.0.0
  + New/Updated features:
  - Support for managing Salt Minion through guest variables.  A new
    open-vm-tools-salt-minion rpm is added to handle this support.
    jsc#SLE-24094 Update open-vm-tools 12.0.0 SLES15SP4
    jsc#SLE-24095 Update open-vm-tools 12.0.0 SLES15SP3
    jsc#SLE-24096 Update open-vm-tools 12.0.0 SLES12SP5
  - New ComponentMgr plugin to manage (add, remove, monitor) components on
    the guest VM.
  - Patch to fix potential Fail to Build from Source [FTBFS] (boo#1196804).
  - Build vmhgfs with either libfuse2 or libfuse3.
  + A number of Coverity and Codacy reported issues have been addressed.
  + The following issues and pull requests reported on
    github.com/vmware/open-vm-tools have been addressed: Issue # 128,
    Issue # 314, Pull # 513, Pull # 544, Pull # 573
- Added patches
  + gcc_size_t.patch (boo#1196804)
* Mon Oct  4 2021 kallan@suse.com
- Update to 11.3.5 (build 18557794) (boo#1190987)
  + New/Updated features:
  - Added a configurable logging capability to the network script.
    The network script has been updated to:
    use vmware-toolbox-cmd to query any network logging configuration from
    the tools.conf file.  Use vmtoolsd --cmd "log ..." to log a message to
    the vmx logfile when the logging handler is configured to "vmx" or when
    the logfile is full or is not writeable.
  - The hgfsmounter (mount.vmhgfs) command has been removed from
    open-vm-tools.
    The hgfsmounter (mount.vmhgfs) command is no longer used in
    Linux open-vm-tools. It has been replaced by hgfs-fuse. Therefore,
    removing all references to the hgfsmounter in Linux builds.
  + Resolved issues:
  - Customization: Retry the Linux reboot if telinit is a soft link to
    systemctl.
  - Open-vm-tools commands would hang if configured with "--enable-valgrind".
  + Spec file updates for:
  - rpmlint errors
  - arg_xmlsec1 --enable-xmlsec1 for better xmlsec1/libxml2 handling.
* Thu Jun 24 2021 kallan@suse.com
- Update to 11.3.0 (build 18090558) (boo#1187567)
  + Resolved issues:
  - The following github issues and pull requests have been resolved:
    446, 481, 500, and 509
  - The following Pull requests have been resolved: 474 and 505
  - A number of issues detected by Coverity, internally or by third parties,
    have been addressed.
  - A command line tool, vmwgfxctrl, has been added to open-vm-tools for
    Linux that can be used to control various aspects of the vmwgfx Linux
    kernel module.  Currently it can both display and set the current
    topology of the vmwgfx kernel driver. It is useful when trying to
    configure custom resolutions on recent Linux distributions, including
    multi-monitor setups.
  - A command line tool, vmware-alias-import, has been added to
    open-vm-tools that can be used to import vgauth config data and apply
    it to the running vgauth service.
  - Enhancements to support or utilize various vSphere features.
- Fixed bug (bsc#1185175) In vmtoolsd.service move deprecated path
  "/var/run" to "/run" for it's PIDfile.
- Update pam-vmtoolsd.patch to compensate for new line numbers.
- Drop patch now contained in 11.3.0:
  - open-vm-tools-glib-2.67.patch
  - open-vm-tools-pollGtk.patch
* Thu May  6 2021 kallan@suse.com
- Add open-vm-tools-pollGtk.patch: Fixes boo#1185103 GCC 11: open-vm-tools
  package fails.
* Fri Mar 26 2021 dimstar@opensuse.org
- Add open-vm-tools-glib-2.67.patch: Fix build with glib 2.67.
  Patch has been borrowed by Fedora, upstream is still busy working
  out a patch (I'd not be surprised if they end up merging this
  finally.
  https://github.com/vmware/open-vm-tools/issues/500
* Mon Mar 15 2021 lnussel@suse.de
- prepare usrmerge (boo#1029961)
* Thu Jan 21 2021 kallan@suse.com
- Update to 11.2.5 (build 17337674) (boo#1180997)
  + Resolved issues:
  - The SUSE specific vmtoolsd PAM configuration file incorrectly referenced
    pam_securetty.so.
  - The following issues and pull requests reported on
    https://github.com/vmware/open-vm-tools have been addressed:
    https://github.com/vmware/open-vm-tools/issues/467
    https://github.com/vmware/open-vm-tools/issues/468
    https://github.com/vmware/open-vm-tools/pull/469
  - A number of Coverity reported errors and false positives have been
    addressed.
  - A complete list of the granular changes that are in the
    open-vm-tools 11.2.5 release is available at:
    https://github.com/vmware/open-vm-tools/blob/stable-11.2.5/open-vm-tools/ChangeLog
- Update pam-vmtoolsd.patch: With the pam_securetty.so entry fixed, only need
  the modified Makefile.am portion of the patch which copies the suse file to
  the /etc/pam.d/vmtoolsd file rather than the default generic file.
* Wed Dec  2 2020 guillaume.gardet@opensuse.org
- Enable build on aarch64
* Mon Nov  9 2020 dimstar@opensuse.org
- Add explicit pkgconfig(gdk-pixbuf-xlib-2.0) BuildRequires: used
  to be pulled in (as part of gdk-pixbuf) by GTK3 in the past. But
  as configure explicitly looks for it, it is our own duty to
  ensure its presence.
* Wed Oct 21 2020 kallan@suse.com
- Update to 11.2.0 (build 16938113) (boo#1177987)
  + Fixed memory leak occurs in disk device mapping information for IDE,
    SATA or SAS (LSI Logic SAS) disks configured in the guest.
  + The following issues and pull requests reported on
    https://github.com/vmware/open-vm-tools have been addressed:
    https://github.com/vmware/open-vm-tools/issues/429
    https://github.com/vmware/open-vm-tools/pull/431
    https://github.com/vmware/open-vm-tools/pull/432
    https://github.com/vmware/open-vm-tools/issues/452
  + A number of Coverity reported errors and false positives have been
    addressed.
  + A complete list of the granular changes that are in the open-vm-tools
    11.2.0 release is available at:
    https://github.com/vmware/open-vm-tools/blob/stable-11.2.0/open-vm-tools/ChangeLog
- Update pam-vmtoolsd.patch (boo#1177987): removed the pam_securetty.so line
  from the new suse file.  Modified the Makefile.am to copy the suse file to
  the /etc/pam.d/vmtoolsd file rather than the default generic file.
* Mon Sep  7 2020 schwab@suse.de
- Use libtirpc also in SLE-15-SP3
* Fri Aug 28 2020 kallan@suse.com
- Update to 11.1.5 (build 16724464) (boo#1175573)
  + This source release rolls up the SDMP fixes release post 11.1.0.
  + Fix serveral Coverity reported issues.
  + Address github issues:
    https://github.com/vmware/open-vm-tools/issues/451
    https://github.com/vmware/open-vm-tools/issues/429
    https://github.com/vmware/open-vm-tools/issues/428
- Drop unnecessary patch:
  - gcc10-warning.patch
  - sdmp-get-version.patch
  - sdmp-netstat-to-ss.patch
  - sdmp-warnings.patch
* Thu Jun 18 2020 kallan@suse.com
- jsc#ECO-2164 for update 11.1.0 (build 16036546) (boo#1171764)
  with new 'Service Discovery' plugin (boo#1171765).
- Reenabled building sdmp in the spec file.
- Added patches (boo#1171765)
  + sdmp-get-version.patch
  + sdmp-netstat-to-ss.patch
  + sdmp-warnings.patch
* Wed Jun 17 2020 kallan@suse.com
- jsc#ECO-2164 for update 11.1.0 (build 16036546) (boo#1171764)
- Fixed bug (bsc#1172693) by removing the 'pam_securetty.so' line from
  pam-vmtoolsd.patch as instructed by vmware (boo#1171003).
  This should fix both (boo#1171003) and (bsc#1172693).
* Wed Jun  3 2020 kallan@suse.com
- VMware has now asked that in updating to 11.1.0 (build 16036546) (boo#1171764)
  to hold off on producing the open-vm-tools-sdmp service discovery plugin
  (boo#1171765) for all SUSE versions due to the plugin's dependency on
  netstat.  Once they have removed the netstat dependency we will need to go
  through the ECO process to get the plugin added.
* Thu May 28 2020 kallan@suse.com
- While updating to 11.1.0 (build 16036546) (boo#1171764) hold off on
  producing the open-vm-tools-sdmp (boo#1171765 Service Discover plugin)
  until it has gone through the ECO process.  Once approved, will resubmit
  to include the plugin.
* Fri May 15 2020 kallan@suse.com
- Update to 11.1.0 (build 16036546) (boo#1171764, boo#1171765)
  + open-vm-tools 11.1.0 includes a new 'Service Discovery' plugin, which
    connects with the vRealize Operations Manager product.  For more
    information and details on configuring this plugin, refer to Configuring
    Service Discovery.
  + In this release, a new tools.conf switch is added to enable and disable
    the guest customization in the guest virtual machine. By default, the
    guest customization is enabled. For more details, refer KB 78903.
- Spec file changes to remove the is_opensuse macros where possible.
- Remoed the mv vm-support line from the spec file.  vm-support is now
  automatically placed in the /usr/bin directory.
- Added version number to Requires: libxmlsec1-openssl1 to help with vgauth
  version checking.
- Added patches
  + pam-vmtoolsd.patch (boo#1171003)
- Drop unnecessary patch:
  - app_info_plugin.patch
  - diskinfo-debug-logging-1162435.patch
  - gcc9-static-inline.patch
* Mon Mar  9 2020 kallan@suse.com
- Simplified the conditional around systemd_ordering to just use
  suse_version >= 1500.
* Fri Mar  6 2020 kallan@suse.com
- Update to 11.0.5 (build 15389592) (boo#1165955)
  + DNS server is reported incorrectly as '127.0.0.53' when using
    systemd-resolved. DNS server is reported incorrectly in GuestInfo as
    '127.0.0.53' , when the OS uses systemd-resolved. This issue is fixed
    in this release.
- Conditionalized the use of systemd_ordering.  Use systemd_ordering
  for factory, openSUSE >= 15, and SLE >= 15.  Use systemd_requires
  for older openSUSE and SLE releases.
- Conditionalize out the use of %%license COPYING for SLE 12 SP2 and older.
- Added patches
  + gcc10-warning.patch (boo#1160408)
  + diskinfo-debug-logging-1162435.patch (boo#1162435 and bsc#1162119)
  - Changed g_warning to g_debug
  + app_info_plugin.patch (boo#1165955)
- Drop unnecessary patch:
  - fix-leaks-Aliases-MappedAliases.patch
* Fri Jan 24 2020 dimstar@opensuse.org
- BuildRequire pkgconfig(udev) instead of udev: allow OBS to
  shortcut through the -mini flavor.
- Use systemd_ordering in place of systemd_requires: systemd is
  never strictly required to run open-vm-tools.
* Fri Oct 11 2019 bjorn.lie@gmail.com
- Add gcc9-static-inline.patch: Fix static inline when building
  with gcc9.
* Wed Oct  9 2019 kallan@suse.com
- Fix memory leak in VixToolsListAuthAliases and VixToolsListMappedAliases.
  (bsc#1153271)
  + Add patch fix-leaks-Aliases-MappedAliases.patch
* Tue Oct  1 2019 kallan@suse.com
- Update to 11.0.0 (build 14549424) (boo#1151523)
  + Added appInfo to publish information about running applications inside the
    guest.
  + Provided sample tool.conf for ease of administration.
- Updated spec file to build 11.0.0
  - Removed libgrabbitmqProxy.so, vmware-guestproxycerttool, and
    guestproxy-ssl.conf
  - Added %%config(noreplace) %%{_sysconfdir}/vmware-tools/tools.conf.example
- Drop unnecessary patch:
  - gcc9-warnings.patch
* Tue Aug  6 2019 kallan@suse.com
- Revert change from (bsc#1133623) update vmtoolsd.service tools to run after
  the network service is ready.  This updated caused cyclic dependencies as
  reported by bugs (bsc#1143452) and (bsc#1141969)
* Tue May  7 2019 kallan@suse.com
- Update vmtoolsd.service tools to run after the network service is
  ready. (bsc#1133623)
- Link VGAuthService to libxmlsec1 rather than libxml-security-c in
  SLES 12 SP3. (bsc#1122435)
* Fri Mar 29 2019 kallan@suse.com
- Update to 10.3.10 (build 12406962) (boo#1130898)
  + Resolved - In certain cases, quiesced snapshots on Linux guests do not
    include backup manifests.
- Drop unnecessary patch:
  - include_log_h_for_g_info.patch
  - no_manifest_on_aborted_snapshot.patch
  - send_vmbackup_event_generic_manifest.patch
  - vmtoolsd_bailout_on_rpc_errors.patch
* Wed Mar 13 2019 kallan@suse.com
- Link VGAuthService to libxmlsec1 rather than libxml-security-c for
  SLES 15 and SLES 15 SP1. It requires libxmlsec1 to be available in the
  base.  VGAuthService is already being linked with libxmlsec1 for
  SLES 12 SP4.  (bsc#1122435)
* Tue Feb 26 2019 mliska@suse.cz
- Add gcc9-warnings.patch (bsc#1126102).
* Fri Feb  8 2019 kallan@suse.com
- Link VGAuthService to libxmlsec1 rather than libxml-security-c in SLE
  products where available. (bsc#1122435)
- Add patches to correct and/or improve handling of certain quiesced snapshot
  failures (bsc#1124397).
  + no_manifest_on_aborted_snapshot.patch
    Don't send a backup manifest when aborting a Linux quiesced snapshot.
  + vmtoolsd_bailout_on_rpc_errors.patch
    Bail out vmtoolsd early when there are RPC errors.
  + send_vmbackup_event_generic_manifest.patch
    Always send VMBACKUP_EVENT_GENERIC_MANIFEST during quiesced snapshots.
  + include_log_h_for_g_info.patch
    Include vmware/tools/log.h to define g_info.
* Tue Jan 29 2019 kallan@suse.com
- Update vmtoolsd.service to support cloud-init customization by default
  by adding "DefaultDependencies=no" and "Before=cloud-init-local.service"
  to the [Unit] section of vmtoolsd.service (bsc#1121964) .
- Copyright year updated in spec file.
* Fri Nov  9 2018 kallan@suse.com
- Update to 10.3.5 (build 10430147) (boo#1115118)
  + While running a quiesced snapshot of a Linux guest on the vSphere hosts
    earlier than version 6.7, open-vm-tools logs warning messages.
  + CreateTemporaryFileInGuest/CreateTemporaryDirectoryInGuest returns a file
    path that does not exist.
  + Excessive spikes of the Memory/Workload percentage metric, in a vRealize
    Operations cluster.
  + open-vm-tools Service running as vmusr crashes on Linux systems which are
    not running on the VMware platform.
- Drop unnecessary patch:
  - false-negative-cloud-init.patch
  - handle-linux-kernel-stat-overflow.patch
  - optional-override-os-name.patch
* Fri Oct 12 2018 kallan@suse.com
- Added Handle Linux kernel /proc FS uint32 type stat overflow when calculating
  (bsc#1110793).
  + handle-linux-kernel-stat-overflow.patch
    On both 32-bit and 64-bit Linux, tools always parses Linux kernel /proc
    FS stats as uint64 values.  For rate stats, current - previous can handle
    uint64 type stat overflow, but not uint32 type.
- Added patch for Optional override for short and long OS names sent from Tools
  (bsc#1047469).
  + optional-override-os-name.patch
    Added support for customers to override the returned long and short OS
    names through the tools config file. If the setting is present, then names
    gathered by hostinfo will be ignored. The user is responsible for setting
    the appropriate names.
- Added patch for Workaround for false negative result when detecting
  cloud-init existance (bsc#1111619)
  + false-negative-cloud-init.patch
    "cloud-init -v" cmd is used to detect if cloud-init is properly configured
    and it works on most linux distros. However in some linux distro like
    Amazon Linux 2, "cloud-init -v" will print result to stderr instead of
    stdout and it makes "forkExecAndWaitCommand" give false negative result.
    1. added a new bool switch in  "ForkExecAndWaitCommand" to choose
    if we should ignore the stderr output when the return code is 0
    2. removed unnecessary reference for "ForkExecAndWaitCommand" in
    linuxDeploymentUtilities.c
    3. trivial change for some formatting
* Wed Aug 15 2018 kallan@suse.com
- After updating the project to include openSUSE_Leap_15.0 and SLE_15, the
  builds for these two projects fail because of unresolved dependencies.
  Some Factory configuration settings were being used for them.  Need to adjust
  the spec file to not use Factory configuration settings for
  openSUSE_Leap_15.0 and SLE_15.
* Fri Aug 10 2018 kallan@suse.com
-  Remove vgauthd.service from the %%pre and %%post section in the spec file.
  This allows vmtoolsd.service to enable vgauthd if needed which creates
  the vmtoolsd.service.requires/vgauthd.service symlink. (bsc#1103868)
- Add Requires: libxmlsec1-openssl1 to the spec file.  This is needed when
  using xmlsec1 rather than xml-ssecurity-c.
* Mon Aug  6 2018 kallan@suse.com
- Update to 10.3.0 (build 8931395)
  + Starting with 10.3.0, open-vm-tools builds with xmlsec1 by default (instead
    of building with xml-security). To revert to the old behavior and build
    with xml-security, use the option '--enable-xmlsecurity' for the
    ./configure command.
  + Add BuildRequires:  libxml2-devel
  + Add BuildRequires:  pkgconfig(xmlsec1) for all openSUSE builds
  + Use --enable-xmlsecurity when building for SLE
- Drop unnecessary patches
  - 100-libtirpc.patch
* Thu May 17 2018 mlatimer@suse.com
- Switch from sunrpc to libtirpc to enable building under
  glibc 2.27 in openSUSE Factory.
  (commit 375d4463c68be3a133e4377655b68cc090cd9511)
  + 100-libtirpc.patch
* Fri Apr  6 2018 mlatimer@suse.com
- Update to 10.2.5 (build 8068406) (boo#1089181)
  + Compatible with supported versions of VMware vSphere ESXi 5.5 and later,
    VMware Workstation 14.0 and VMware Fusion 10.0.0.
  + Quiesced snapshot: Ability to exclude specific file systems from
    quiesced snapshots on Linux guest operating systems. For more details,
    see [Documentation](https://docs.vmware.com/en/VMware-Tools/index.html)
  + Disable display mode setting: A configuration option is introduced to
    disable normal display mode setting functionality using open-vm-tools.
    For more details, see [KB 53572](https://kb.vmware.com/s/article/53572).
- Drop unnecessary patches
  - udev_rules-disk-devs-only.patch
* Tue Feb 13 2018 dimstar@opensuse.org
- Stop depending on the meta-package xorg-x11-devel as
  BuildRequires, but use the explicit module names configure is
  looking for: pkgconfig(sm), pkgconfig(xcomposite),
  pkgconfig(xext), pkgconfig(xi), pkgconfig(xinerama),
  pkgconfig(xrandr), pkgconfig(xrender) and pkgconfig(xtst).
* Thu Dec 21 2017 mlatimer@suse.com
- The VMware provided open-vm-tools-deploypkg is now obsoleted.
* Fri Dec 15 2017 mlatimer@suse.com
- Update to 10.2.0 (build 7253323) (boo#1073174)
  + Fix memory leak in vmtoolsd.
  + Add SUSE Server for SAP Applications to hostinfoPosix.c
  + Fix crash issue when stopping vmtoolsd(vmuser).
  + Add new GOS definitions (e.g. SLES 15) for virtual hardware version 14.
  + Add /usr/bin/vmware-user symlink to vmware-user-suid-wrapper.
  + Provide vmware-vgauth-smoketest, for VGAUthservice validation.
- Modify udev rules to only adjust timeout on disk devices (bsc#1063320)
  + udev_rules-disk-devs-only.patch
- Due to a hard dependency on glibc 2.12, open-vm-tools 10.2.0 no longer
  builds for SLES11. Remove all SLES11 specific options in spec file.
- Drop unnecessary patches
  - Report-SLES12-SAP-guest-OS-as-SLES12.patch
  - resolutionKMS-wayland.patch
  - fix_discards_qualifiers_warning.patch  (only applicable to SLES11)
* Fri Oct 13 2017 mlatimer@suse.com
- Build deploypackage plugin for SLES11 (bsc#1062837)
  (The VMware provided open-vm-tools-deploypkg is now obsolete.)
- Enable building with ssl capabilities for SLES11.
  +fix_discards_qualifiers_warning.patch
* Fri Oct  6 2017 mlatimer@suse.com
- Update to 10.1.15 stable release
  + Tools Hgfs Plugin: refresh Hgfs drives on client start
  + Report version data via guestinfo vars
  + Add entries for MacOS 10.13 (High Sierra) to guest_os_tables.h
* Mon Aug 21 2017 mlatimer@suse.com
- open-vm-tools fails to correctly set screen resolution under
  Wayland environments (boo#1054800)
  + resolutionKMS-wayland.patch
* Tue Aug 15 2017 mlatimer@suse.com
- Update to 10.1.10 stable release (boo#1051977, bsc#1052129)
  + Map certain PAM errors to VGAUTH_E_AUTHENTICATION_DENIED.
  + Exclude non-directory and non-existing paths during quiescing.
  + Fix timesync state to be uncalibrated when adjustment is large
    (>60ms).
  + Fix an invalid class pointer access when the VSS provider is
    not installed.
  + Add support for the new selection target name "text/rtf" for
    copy/paste.
  + VMCI: reset datagram buffer pointer on dealloc
  + randomly generate tmp directory name
  + Previously Common Agent Framework (CAF) builds were linking against
    specific versions of PCRE and libiconv.  That restriction has been
    removed.
  + Reverts commit 7023998ba5594871a658c5ef1be4dbda6c0158eb to prevent
    intermittent hangs during soft reboots of RHEL 6.8 Linux VM.
  + Includes fix for VMs freezing during snapshots (bsc#1051627)
    (Thaw filesystems if the snapshot commit message to VMX fails.
    Commit b443e6456ffda66c0279032ab932ef271f8e1ae6)
- Drop unnecessary patch:
  + glibc-sysmacros.patch
* Fri Mar 31 2017 ken@suse.com
- Fix unowned /var/lib/vmware directory. (bsc#1028866)
- Fix package dependency for open-vm-tools on libvmtools0 (bsc#1031968)
* Mon Mar 27 2017 ken@suse.com
- fix build failure caused by upstream glibc change requiring
  explicit include of sys/sysmacros.h
  + glibc-sysmacros.patch
* Thu Mar  9 2017 ken@suse.com
- Updated to 10.1.5 stable release (boo#1027987)
  + Authentication failure is reported as unknown general system error.
  + Unable to backup virtual machines with active Docker containers.
* Mon Feb 20 2017 kukuk@suse.de
- Don't require insserv if we don't need it.
* Tue Feb  7 2017 ken@suse.com
- Sumbitting update for SLE11SP4, SLE12SP1, SLE12SP2
  see fate#322214 & fate#322218
* Wed Dec 14 2016 sparschauer@suse.de
- Report SLES12-SAP guest OS as SLES12 (bsc#1013496)
  + Report-SLES12-SAP-guest-OS-as-SLES12.patch
* Thu Dec  1 2016 ken@suse.com
- Remove building KMP modules. No longer needed or wanted for
  current releases. User space tool vmhgfs-fuse has replaced the
  need for vmhgfs kernel module.
* Sat Nov 12 2016 ken@suse.com
- Updated to 10.1.0 stable release (boo#1011057)
  + vmware-namespace-cmd command line utility.
  + gtk3 support
  + Common Agent Framework (CAF)
  + guest authentication with xmlsec1
  + FreeBSD support
  + sub-command to push updated network information to the host on demand
  + udev rules for configuring SCSI timeouts in the guest
  + fixes for Ubuntu 16.10
  + Fix for quiesced snapshot failure leaving guest file system
    quiesced (bsc#1006796)
  + Fix for CVE-2015-5191 (bsc#1007600)
- Dropped upstream patches included (or not necessary) in 10.1.0:
  + vmw-bitmask-gcc6.patch
  + no-unused-const.patch
  + enable-gcc46+.patch
* Wed Nov  2 2016 jcejka@suse.de
- Add udev rule to increase VMware virtual disk timeout values
  (bsc#994598)
  [99-vmware-scsi-udev.rules]
* Wed Jul 13 2016 ken@suse.com
- Fix vmtoolsd init script to run vmtoolsd in background. (bsc#971031)
  + fix originally done in SLE-11-SP4 code base by tcech@suse.cz
* Thu Jun 16 2016 ken@suse.com
- Added patches for GCC 6 build failure (boo#985110)
  + vmw-bitmask-gcc6.patch
  + no-unused-const.patch
* Wed Jun  8 2016 ken@suse.com
- Update to 10.0.7-gtk3 stable branch
  + add support for gtk3, needed by the dndcp and resolutionset
    plugins
  + remove files generated by autoreconf
  + a few minor build fixes
- Update fixes copy-n-paste and drag-n-drop regressions (bsc#978424)
- Added new vmblock-fuse.service
- Drop upstream patches included (or not necessary) in 10.0.7-gtk3:
  + open-vm-tools-posixly.patch
  + open-vm-tools-buildsystem-fixup.patch
* Fri Apr 29 2016 afaerber@suse.de
- Sanitize the filename handling some more. The official GitHub
  filename is open-vm-tools-stable-10.0.7.tar.gz.
* Thu Apr 28 2016 ken@suse.com
- Update to 10.0.7 stable branch
  + Added namespace command line utility "vmware-namespace-cmd".
* Fri Apr 22 2016 jslaby@suse.com
- they renamed open-vm-tools-stable-10.0.5.tar.gz to
  stable-10.0.5.tar.gz -- fix .spec accordingly
* Wed Apr 20 2016 dimstar@opensuse.org
- Add open-vm-tools-posixly.patch: defined(linux) is not posix
  compliant and modern compilers no longer accept it. Change to
  defined(__linux__)
  https://github.com/vmware/open-vm-tools/pull/81
- Add open-vm-tools-buildsystem-fixup.patch: since libsigc++ injects
  - std=c++11 into CFLAGS, the various objects in open-vm-tools need
  to be split up a bit in order to not have a mixed C/C++ object
  receiving the same CFLAGS.
* Wed Dec 23 2015 mlatimer@suse.com
- Compile without gtkmm support for SLES12 based environments
  (which do not provide gtkmm2.4)
* Tue Dec  1 2015 mlatimer@suse.com
- Update to 10.0.5 stable branch
  + [vgauth] fix timestamp check
  + [libresolutionSet.so] Add an error handler to X11 resolutionSet
  + [vmci.ko] Kill tasklet when unloading vmci module
  + [libvmbackup.so] Quiesced snapshots Skip freezing autofs mounts.
  + [vmhgfs.ko] make vmhgfs compatible with Linux kernel 4.2
* Fri Oct 30 2015 mlatimer@suse.com
- Enable vgauth for openSUSE Leap 42.1 (bsc#952645)
* Thu Oct 22 2015 mlatimer@suse.com
- Remove vgauth requirements from vmtoolsd.service file if vgauth
  is not enabled.
- Remove gcc4.7 requirement for older environments.
* Wed Sep  9 2015 mlatimer@suse.com
- Enable certificate-based access control via SAML tokens (vgauth) on
  openSUSE Factory.
* Thu Sep  3 2015 mlatimer@suse.com
- Update to open-vm-tools-10.0.0-3000743  (boo#944615)
  + Common versioning
  + Quiesced snapshots enhancements for Linux guests running IO workload
  + Shared Folders (Linux kernel 4.0.0 and higher only)
  + ESXi Serviceability
  + GuestInfo Enhancements
  + Internationalization, with support for:
    + English
    + French
    + German
    + Spanish
    + Italian
    + Japanese
    + Korean
    + Simplified Chinese
    + Traditional Chinese
  + Compatibility with all supported versions of VMware vSphere, VMware
    Workstation 12.0 and VMware Fusion 8.0
- Drop upstream patches included (or not necessary) in 10.0.0:
  - 0001-Fix-vmxnet-module-on-kernels-3.16.patch
  - 0002-Fix-d_alias-to-d_u.d_alias-for-kernel-3.18.patch
  - 0003-Fix-f_dentry-msghdr-kernel-3.19.patch
  - 0004-vmhgfs-bdi-kernel-4.0.patch
  - xutils-add-cstring.patch
- Remove vmhgfs define to ensure vmhgfs is always built
- Only build kernel modules for versions <= openSUSE 13.2
* Wed Sep  2 2015 mlatimer@suse.com
- Do not attempt to start vmware-vmblock-fuse if vmware-vmblock-fuse
  (included with the -desktop package) is not installed (bsc#943236)
* Wed Aug 12 2015 dimstar@opensuse.org
- For SLE11, the KMP is still required; the .spec file logic is
  now only enabled in the linked package, the 2nd spec file must
  not be part of the main package open-vm-tools (as Factory would
  immediately create the linked package, which would fail building
  with Linux 4.x) (boo#941384).
* Mon Aug 10 2015 dimstar@opensuse.org
- Drop KMP related .spec and .changes file (bsc#938593) (for now
  we keep the logic in the .spec file, in case we want to resurrect
  it).
* Mon Jul 13 2015 mlatimer@suse.com
- Update to open-vm-tools-9.10.2-2822639
  + Fix various compilation errors
  + Retry sending vmbackup event with elevated privileges
  + Add a -h option to vgauth
  + Workaround NFS open bug by retrying on ESTALE
  + Fix the HGFS protocol opcode to differentiate headers
  + Thaw filesystems when the snapshot commit message to VMX fails
- Drop upstream patches included in 9.10.2:
  - toolboxcmd-fix-logic.patch
  - asm_x86.patch
* Sun Jun 28 2015 antoine.belvire@laposte.net
- Fix compilation issues with GCC 5:
  * Add toolboxcmd-fix-logic.patch
  * Add asm_x86.patch
* Thu May 21 2015 mlatimer@suse.com
- Build using gcc4.7 for SLES11 environments to avoid mul64.h
  dependency problem for i586 architectures
- Include cstddef to resolve compile problems under gcc4.7
  enable-gcc46+.patch
- Ensure xutils builds properly under older versions of gcc
  xutils-add-cstring.patch
- Prevent files on shared folders from being truncated to 0 bytes
  under 4.0 kernel
  0004-vmhgfs-bdi-kernel-4.0.patch
* Mon May 18 2015 mlatimer@suse.com
- Update to open-vm-tools-9.10.0-2476743:
  + vgauth added
  + deploypkg added
  + guest proxycerttool added
  + hgfs and vmci/vsock fixes
  + asyncsocket enhancements
  + library fixes and improvements
  + locking and logging fixes and improvements
  + foundry fixes
  + vm-support script fixes
- Replace obsolete patches with rebased versions (from ArchLinux):
  - Drop 0001-Remove-unused-DEPRECATED-macro.patch
  - Drop 0002-Conditionally-define-g_info-macro.patch
  - Drop 0003-Add-kuid_t-kgid_t-compatibility-layer.patch
  - Drop 0004-Use-new-link-helpers.patch
  - Drop 0005-Update-hgfs-file-operations-for-newer-kernels.patch
  - Drop 0006-Fix-vmxnet-module-on-kernels-3.16.patch
  - Drop 0007-Fix-vmhgfs-module-on-kernels-3.16.patch
  - Drop 0008-Fix-segfault-in-vmhgfs.patch
  - Drop open-vm-tools-linux-3.17.7.patch
  - Drop open-vm-tools-linux-3.17.patch
  - Drop open-vm-tools-linux-3.18.0.patch
  - Add 0001-Fix-vmxnet-module-on-kernels-3.16.patch
  - Add 0002-Fix-d_alias-to-d_u.d_alias-for-kernel-3.18.patch
  - Add 0003-Fix-f_dentry-msghdr-kernel-3.19.patch
- Add libmspack BuildRequires (deploypkg).
- Add openssl BuildRequires (grabbitmqproxy and vgauth).
- Compile using --without-xmlsecurity and --without-xerces as
  pkgconfig(xml-security-c) is not yet available in the build service,
  (disables vgauth support).
- Disable deploypkg for older versions of SLES and openSUSE.
- Disable ssl for older versions of SLES and openSUSE (disables
  grabbitmqproxy and vgauth).
- Update spec file to be compatible with SLES and openSUSE.
- This update also addresses a suspend with systemd issue (bsc#913727)
* Tue May  5 2015 dimstar@opensuse.org
- Handle kernel 4.0: we can't just compare the 'minor' part of the
  version anymore when applying patches.
* Thu Mar 12 2015 mlatimer@suse.com
- Prevent autoinstallation of open-vm-tools in SLES11SP4 environments
  due to potential conflict with VMware tools. (bsc#921618)
* Thu Feb 19 2015 dimstar@opensuse.org
- Add open-vm-tools-linux-3.19.0.patch: Fix building of vmhgfs with
  Kernel 3.19.0+.
* Wed Jan 21 2015 mlatimer@suse.com
- Remove modprobe of deprecated vmsync module from SysV init script.
* Fri Jan 16 2015 mlatimer@suse.com
- Update specfile to ensure kernel modules are not built or required
  for SLES11SP4 and SLES12.
* Fri Jan  9 2015 mlatimer@suse.com
- Use fuse-devel instead of pkgconfig(fuse) in SLES11SP4.
* Mon Jan  5 2015 dimstar@opensuse.org
- Add open-vm-tools-linux-3.17.7.patch: Fix building of vmhgfs with
  Kernel 3.17.7+.
- Add open-vm-tools-linux-3.18.0.patch: Fix building of vmhgfs with
  Kernel 3.18.0+.
* Mon Jan  5 2015 dimstar@opensuse.org
- Split building of KMPs into own spec file: open-vm-tools-KMP:
  the resulting KMP packages keep their existing name, as this is
  handled through the kernel_package macros. This split allows to
  work around boo#905420.
* Sat Nov 29 2014 ledest@gmail.com
- fix bashisms in vmware-user-autostart-wrapper script
* Wed Nov 12 2014 dimstar@opensuse.org
- Add open-vm-tools-linux-3.17.patch: Fix build with Linux 3.17.0.
* Mon Nov 10 2014 dimstar@opensuse.org
- Sync up patches with ArchLinux:
  + Added 0001-Remove-unused-DEPRECATED-macro.patch
  + Added 0002-Conditionally-define-g_info-macro.patch
  + Added 0003-Add-kuid_t-kgid_t-compatibility-layer.patch
  + Added 0004-Use-new-link-helpers.patch
  + Added 0005-Update-hgfs-file-operations-for-newer-kernels.patch
  + Added 0006-Fix-vmxnet-module-on-kernels-3.16.patch
  + Added 0007-Fix-vmhgfs-module-on-kernels-3.16.patch
  + Added 0008-Fix-segfault-in-vmhgfs.patch
  + Droped g_info_redefine.patch (now named
    0002-Conditionally-define-g_info-macro.patch).
- Enable building of KMP packages.
* Mon Nov 10 2014 ledest@gmail.com
- Fix bashisms in preun script.
* Fri Oct 31 2014 crrodriguez@opensuse.org
- Do not generate timestamps in the doxygen docs.
* Mon Oct 20 2014 dimstar@opensuse.org
- Add -Wno-cpp to CFLAGS.
* Mon Oct  6 2014 boris@steki.net
- Updated to latest release 9.4.6-1770165
  + Release matching the vSphere 5.5p02 release
- "which" as separate package does not exist on older opensuse versions
  so removed from Requires for older distributions
- used autoreconf as source package does not provide configure script anymore
- removed vmsync module from OS12.3 build target as it does not compile
* Fri May 16 2014 mlatimer@suse.com
- Modify vmware-user-autostart-wrapper to unconditionally start
  vmware-user-suid-wrapper, and no longer delay for vmblock-fuse
  if under systemd. (bnc#876074)
* Wed May 14 2014 meissner@suse.com
- added forgotten %%pre snippet for service addition, this made
  systemd service not auto-start. bnc#870737
* Mon Apr 28 2014 mlatimer@suse.com
- Move 'vm-support' script from /etc/vmware-tools to /usr/bin (bnc#874931).
- Update call to "tools.set.version" RPC during uninstall to match upstream
  behavior (bnc#875129).
- Add missing RPM runtime dependencies (net-tools, tar, which).
* Mon Mar 17 2014 mlatimer@suse.com
- Update to version 9.4.0:
  + Release of open-vm-tools matching vSphere 5.5.
- Remove build dependency on liburiparser (no longer necessary).
- Removed obsolete --disable-unity configure option.
- Use doxygen to generate devel docs.
- Require libprocps for openSUSE 12.3 and above.
- Added CUSTOM_PROCPS_NAME=procps (required for 9.4.0 build).
- Add g_info_redefine.patch: Fix redefine warnings during build.
- Add vmtoolsd.service for use with systemd.
- Drop open-vm-tools.permissions: No longer required.
- Only build kmp for specified distributions, and only require kernel-source
  when kernel modules are being built.
- Rename -gui package to -desktop.
* Sat Nov  2 2013 dimstar@opensuse.org
- Supplement the -gui package on xorg-x11-server instead of
  xorg-x11 as the latter is only a meta-package, that is not
  installed on all machines (bnc#848505).
* Tue Sep 10 2013 dimstar@opensuse.org
- Really drop open-vm-tools-kernel-3.8.patch (osc rm).
- Drop open-vm-tools-kernel-3.6.patch: fixed upstream.
- Inject -Wno-unused-local-typedefs into CFLAGS.
- Only build vmsync up to openSUSE 12.3.
- Disable build of vmhgfs (and related tools) on openSUSE > 12.3,
  as the module fails and VMWare is unresponsive in providing a
  fix. Maybe one day, when there is actual commitment, the module
  and the related tools / mount-helpers can be re-enabled (see also
  bnc#834369).
- Wrap the KMP Package in a condition to only build when there are
  actually modules to be built (vm_modules not empty).
- Do not require vmware-guest-kmp from the main package if we do
  not built KMP packages (if there are no modules to be built).
* Mon May 13 2013 dimstar@opensuse.org
- Update to version 9.2.3:
  + Fixes for HGFS driver to compile on newer kernels (3.9).
  + Fix for HGFS performance regression..
  + vmci/vsock drivers are disabled on kernels 3.9 and above.
  + vmblock driver is disabled on kernels 3.0+.
  + Fix and re-enable Copy/Paste on Solaris.
  + Configure script will detect procsps-ng library.
  + Suppress deprecated warnings coming form newer glib.
- Drop open-vm-tools-kernel-3.8.patch: fixed upstream.
- No longer build vmci and vsock for openSUSE > 12.3; they have
  been included in the mainline kernel.
* Wed Apr 24 2013 dimstar@opensuse.org
- Add open-vm-tools-kernel-3.8.patch: Fix build with kernel 3.8.x.
* Wed Apr  3 2013 dimstar@opensuse.org
- Update to version 9.2.0:
  + Fixes for HGFS driver to compile on newer kernels (3.6).
  + vmsync driver is disabled on kernels 3.0+ as vmbackup plugin
    uses FIFREEZE/FITHAW standard ioctls.
  + Fixes for Copy/Paste (and C&P is temporarily disabled on
    Solaris due to C++ library issues).
- Rebase open-vm-tools-kernel-3.6.patch: mostly fixed upstream.
- No longer build vmblock.ko: it's been obsoleted in favor of
  vmblock-fuse.
- Change vmtoolsd to use vmware-vmblock-fuse instead of vmblock.ko,
  using the new mount point /var/run/vmblock-fuse.
- Add fuse Requires, as we now use vmblock-fuse.
  * Fixes bnc#803157.
* Sat Mar  2 2013 coolo@suse.com
- update license to new format
* Fri Oct 12 2012 dimstar@opensuse.org
- Update to version 9.2.0:
  + Release of open-vm-tools matching Workstation 9.0.
- Drop kernel-3_4.patch: fixed upstream.
- Add open-vm-tools-kernel-3.6.patch: Fix build with kernel 3.6.
- Add pkgconfig(fuse) BuildRequires: Support vmhgfs fuse.
* Sat Aug  4 2012 dimstar@opensuse.org
- autostart-wrapper: unset SESSION_MANAGER. This helps newer
  gnome-session versions to not try to track this task. Due to the
  double fork() it gets it wrong and delays logout (waiting for a
  timeout to terminate this user task) (bgo#681904).
* Fri Jun  8 2012 jreidinger@suse.com
- Add kernel-3_4.patch: Fix build for kernel-3.4.
* Fri Apr  6 2012 dimstar@opensuse.org
- Update to version 8.8.2:
  + Updated code for compatibility with newer Linux kernel
    releases.
  + Minor tweaks in Unity and Resolution set plugins
- Drop vmhgfs-2011.12.20.patch: fixed upstream.
* Fri Mar 30 2012 dimstar@opensuse.org
- Build vmci as first module and copy Modules.symvers to source of
  all subsequent modules to be built. Fixes issues where vmhgfs for
  example does not have all symbols available and fails to load
  [bnc#703959].
* Fri Mar 30 2012 dimstar@opensuse.org
- Add a tools.conf to the package. All settings are left to default
  except [guestinfo] / disable-perf-mon=1, which resolves
  bnc#698181.
* Thu Mar 15 2012 prusnak@opensuse.org
- added call to vmware-rpctool in %%preun to unset the installed
  version [bnc#748517]
* Sun Feb  5 2012 dimstar@opensuse.org
- Add vmhgfs-2011.12.20.patch: Fix build of vmhgfs module with
  kernel 3.2.
- Update FSF address part in vmtoolsd header.
* Tue Jan 24 2012 prusnak@opensuse.org
- Update to version 8.8.1 (Stable series):
  * Updated code for compatibility with newer Linux kernel releases
    and with newer NetworkManager releases.
- dropped vmxnet+kernel-3.0 (not needed anymore)
- build with PIE [bnc#743130]
* Wed Sep 21 2011 dimstar@opensuse.org
- Update to version 8.8.0 (Stable series):
  + This release of open-vm-tools matches the VMware Tools package
    released with Workstation 8.0 and Fusion 4.0.
    It's targeted at desktop users who want the latest features in
    (VMware's) Unity, HGFS and drag & drop support.
- Add open-vm-tools-vmxnet+kernel-3.0.patch: HAVE_NETDEV_PRIV is
  gone in kernel 3.0 and netdev_priv is in kernel since 2.6.6.
- use set_permissions instead of run_permissions on 11.4+
* Thu Jul 21 2011 dimstar@opensuse.org
- Update to version 2011.07.19:
  + Fix an issue in the HGFS driver that could lead to a kernel
    panic.
  + Update some code to support new compiler and kernel versions.
  + Minor bug fixes and code cleanup.
- Changes from version 2011.06.27:
  + A few enhancements to Unity: XFCE support, better interaction
    with "the other" (Ubuntu's) Unity and compositing window
    managers, better X error handling, and a few bug fixes.
  + few bug fixes in HGFS, and minor bug fixes in other components.
  + Otherwise, mostly code cleanup.
* Thu Jun  2 2011 prusnak@opensuse.org
- updated to 2011.05.27:
  + Mostly cleanups and a few bug fixes.
- fixes [bnc#673267] [bnc#690491]
* Tue May 31 2011 prusnak@opensuse.org
- use -Wno-unused-but-set in optflags so it will not fail build
  while using -Werror
* Wed May 25 2011 prusnak@opensuse.org
- added check in initscript whether VMTOOLSUSER_BIN exists
* Fri Apr 29 2011 dimstar@opensuse.org
- Udpate to version 2011.04.25:
  + Mostly cleanups and small bug fixes in this release.
  + Logging is enabled by default in vmtoolsd, writing to syslog.
    The default log level is not chatty, so few messages should
    make it to syslog during normal operation.
  + The GUI version of the toolbox was removed.
* Wed Apr 27 2011 dimstar@opensuse.org
- Extend the init script to detect the name of the balloon driver,
  which changed several times in the kernel.
* Thu Apr 14 2011 dimstar@opensuse.org
- Update to 2011.03.28:
  + HGFS mounter and vmusr's suid wrapper were changed to avoid
    issues with symlink attacks. A new mount utility for vmblock on
    Solaris and FreeBSD was added.
  + The VMCI driver was thoroughly reworked so that it can serve as
    both the host and guest VMCI driver. This is mostly targeted at
    supporting nested VMs.
  + vmusr got better integration with X's session manager,
    including proper cleanup during session teardown.
  + Unity has been enhanced to better handle some desktop
    environments.
  + Many small bug fixes in other areas, including updates for
    newer Linux kernels.
- Changes from 2011.02.23:
  + Some copy & paste issues with KDE were fixed.
  + Mostly cleanups and bug fixes, with a few build enhancements.
- Changes from 2011.01.24:
  + Mostly cleanups and bug fixes.
  + Install code fixed to handle translation catalogs correctly.
- No longer care for missing modules on openSUSE 11.2. It is EOL in
  a few weeks. As a consequence, remove the sources (they are in
  current kernels):
  + pvscsi.tar.bz2
  + vmxnet3.tar.bz2
  + vmemctl.tar.bz2
- Fix some lint warnings: obsolete only <, not <=, Add PreReq:
  permissions to the -gui package.
* Thu Apr 14 2011 dimstar@opensuse.org
- Fix build with Factory: verify the list of modules that are not
  yet merged into the main kernel.
* Wed Dec 22 2010 dimstar@opensuse.org
- Update to version 2010.12.19:
  + New version of DnD code lands in open-vm-tools. The host part
    of the new DnD protocol is not available yet in VMware
    products, though.
  + vmtoolsd gets some new functionality to support new features
    being developed internally.
  + vmxnet driver for FreeBSD fixed to allow changing the MAC
    address.
  + lots of bug fixes and other cleanups in various areas.
- Re-enable building of X dependenices (with_X 1)
- Disable unity on openSUSE < 11.4. It requires glib >= 2.24.
* Thu Nov 25 2010 dimstar@opensuse.org
- Re-Inject pvscsi for older kernel builds.
* Mon Nov 22 2010 dimstar@opensuse.org
- Update to version 2010-11-17:
  + Mostly cleanups and bug fixes.
  + vmxnet3 on Solaris now supports jumbo frames.
- For all older updates, please see NEWS.
- Add an easy way to enable/disable X tools. Those currently fail
  to build.
- Drop open-vm-tools-libpng14.patch: upstream fixed.
* Mon Jun  7 2010 dimstar@opensuse.org
- Add vmmemctl.tar.bz2, extracted from open-vm-tools 2010.02.23.
* Mon May 31 2010 dimstar@opensuse.org
- Better logic to easily disable modules that got inlcluded in the
  Linux Kernel, for bnc#605085.
* Thu Apr 22 2010 dimstar@opensuse.org
- Re-introduce vmxnet3 on openSUSE <= 11.2. Up to then we have
  kernel 2.26.31, which does not bring the vmxnet3 driver yet.
  The driver itself is the last one shipped with open-vm-tools,
  version 2009.12.16.
* Wed Apr 21 2010 dimstar@opensuse.org
- Send SIGUSR1 to vmware-user process when the services are being
  stopped. This possibly solves bnc#544400.
* Wed Apr  7 2010 dimstar@opensuse.org
- Add open-vm-tools-libpng14.patch to fix build with libpng 1.4.
* Wed Mar 24 2010 dimstar@opensuse.org
- Update to 2010.03.20:
  + New i18n support for Tools; it is based on VMware's internal
    tools
  + Logging infrastructure has been enhanced and now supports
    rotation
  + Bug fixes in several areas (DnD, backup support, thread safety)
  + Updates in Linux kernel modules for compatibility with newer
    kernels.
  + New functionality in the Unity support code.
* Tue Mar 23 2010 dimstar@opensuse.org
- Disabled vmxnet3 building. this only did not give an error anyhow
  as there was a typo, thus having the module already disabled for
  quite some time.
- bnc#590329: Re-add lost 50-vmnics.conf file.
* Thu Feb 25 2010 dominique.leuenberger@tmf-group.com
- Update to 2010.02.23:
  + Mostly bug fixes, cleanups and code refactoring.
* Wed Feb 10 2010 dimstar@opensuse.org
- Update to 2010.01.19:
  + Linux modules have been updated to compile on newer kernels
  + Solaris modules now should compile on OpenSolaris
    (tested on 2009.06).
  + Other than those, mostly bug fixes and minor refactoring.
* Wed Jan  6 2010 dimstar@opensuse.org
- Update to 2009.12.16:
  + Some improvements to vmtoolsd, base libraries and and the
    plugin interface.
  + Some library refactoring: use new lock library, changes to
    support compilation of some code on ARM.
  + some fixes in configure.ac to try to correctly support newer
    distros.
  + vsock/vmci improvements.
  + bug fixes in the vmxnet / vmxnet3 drivers, and FreeBSD's
    vmblock driver.
  + vmxnet3 for Linux is now upstream (as of Linux 2.6.32), and
    will be removed from later releases of open-vm-tools.
  + pvscsi will be available upstream starting with Linux 2.6.33
    and at that time will be removed from open-vm-tools.
- Disable building of vmxnet3 if kernel is 2.6.32 or newer.
* Mon Nov 23 2009 dimstar@opensuse.org
- Update to 2009.11.17
  + Lots of refactoring and cleanup in the code, mainly targeting
    the definition of a set of public APIs.
  + vmblock-fuse can now replace the vmblock kernel module for DnD
    operations.
  + Fix some memory leaks in the guestInfo module.
* Sun Nov 22 2009 dimstar@opensuse.org
- Update to 2009.10.15
  + The HGFS module got some performance enhancements.
  + Minor enhancements to vmtoolsd and the logging system.
  + Fix for a few issues reported on the sourceforge bug tracker.
  + Lots of code refactoring, and a few bug fixes.
* Sat Nov 21 2009 dimstar@opensuse.org
- Update to 2009.09.18
  + Mostly bug fixes and minor enhancements.
  + The pvscsi code was re-factored in preparation for upstreaming.
    The driver has been sent to the LKML for inclusion in the main
    Linux tree and might be removed from open-vm-tools once it's
    accepted.
* Mon Aug 10 2009 dimstar@opensuse.org
- Update to 2009.08.24
  + Remove support for Linux kernels < 2.6.9.
  + The vsock now implements a new notification protocol that has
    better performance than the previous.
  + New infrastructure for sending more network config-related
    information about the virtual machine to the host.
  + Other bug fixes and minor improvements to the code.
* Sat Aug  8 2009 dominique-obs@leuenberger.net
- move libguestlib.so to the devel pakage, which we have since
  version 2009.07.22 and remove the rpmlint check for it.
- Remove the autoreconf call. We do not patch any Makefiles anymore.
- Require libvmtools0 from the -devel package.
- Drop the rpmlintrc file. Permissions are correctyl set, devel
  package split out.
* Thu Aug  6 2009 meissner@suse.de
- Adjust specfile permission handling to match SUSE standard, snippet
  moved to permissions package. bnc#474285
* Thu Jul 23 2009 dominique-obs@leuenberger.net
- Update to 2009.07.22
  * Better support for dkms by means of a script to help create a
    dkms tree.
  * "make install" now also installs header files for public
    libraries, plus a few fixes to incorrect install behavior.
  * Lots of improvements to the new DnD code.
  * This will be the last release with support for Linux
    kernels < 2.6.9.
- fix compatibiliy update script to redirect stderr to /dev/null
  (in case the script is not found, do not scare the user)
* Tue Jul 21 2009 prusnak@suse.cz
- added || : to modprobe -r and umount calls in vmtoolsd [bnc#523342]
* Fri Jun 19 2009 dominique-obs@leuenberger.net
- Updated to 2009.06.18
  * Mostly a bug fix release.
  * vmhgfs now is able to use vsock as a transport (although
    backend support for HGFS over vsock is not yet released in
    VMware products).
- Removed patch open-vm-tools-wiperPosix.patch. An alternative
  solution was integrated upstream
- Dropped patch open-vm-tools-rpath.patch: merged upstream
* Sat May 23 2009 dominique-obs@leuenberger.net
- Updated to 2009.05.22
  * Mostly a cleanup and bug fix release.
  * Fix a build issue where a symlink attack could cause the
    open-vm-tools build to overwrite data (by placing a symlink in
    /tmp).
  * Second (and last?) batch of changes to clean up duplicate files
    in the source tree, including Solaris and FreeBSD kernel
    modules andother module-specific shared files.
  * Plugins now are properly built using plugins_LTLIBRARIES so
    that "-rpath" doesn't need to be used (this would cause an
    RPATH entry to be added to the final binary, which some tools
    didn't like).
  * open-vm-tools now properly detects PAM and enables PAM support
    in the code.
- Removed -rpath.patch. Variation of it integrated upstream
- Added patch to consume (-wiperPosix.patch) the result of fgets
- BuildRequires pam-devel
- The pam miss-naming on x86_64 has been fixed upstream
- Add a new -rpath patch. Not everything is solved upstream.
- Delete arch dependent files from /usr/share (not yet needed)
* Sat Apr 25 2009 dominique.leuenberger@tmf-group.com
- Upgrade to snapshot 2009.04.23
  * Implemented copy & paste support for RTF data and file contents.
  * guestd has been removed from open-vm-tools; vmtoolsd is now the only
    option for the main tools service.
  * Added vmblock and vmmemctl modules for Solaris (under the CDDL).
  * vmware-user can now work with both vmblock-fuse and vmblock.
  * Linux HGFS now has a stream-based (TCP, vsock) transport, still under
    development.
  * First batch of changes to cleanup duplicated files in the source tree.
    Most duplicated files in the Linux kernel modules have been cleaned up.
- Extensive rewrite of the spec file:
  * make use of the now upstream provided make install
  * configure --no-root-privileges, to not install mount.vmhgfs as suid
- Add patch open-vm-tools-2009.04.23-rpath.diff: removes the rpath logic
  which was introduced for the vmusr and vmsvc plugins. libtools is broken
  in this respect. (patch submitted upstream for review)
- Extend preun section with  service rename (vmware-guest -> vmtoolsd)
  (patch provided by prusnak)
- forcibly activate vmtoolsd service also on update.
- fix up the KMP rename: for this to work we need to provide / obsolete
  vmware-kmp and vmware-kmp-<kernelflavor>; otherwise, zypper starts pulling
  in other kernels.
* Fri Mar 20 2009 dominique@leuenberger.net
- rename vmware-KMP to vmware-guest-KMP for easier identification
  of the use and to avoid confusion (users installing the KMP on the
  vmware hosts) (bnc#481137)
- create subpackage libvmtools0
* Thu Mar 19 2009 dominique@leuenberger.net
- Upgrade to snapshot 2009.03.18
  * Mostly a bug fix release.
  * The new DnD V3 protocol is now available in open-vm-tools.
  * vmtoolsd is now preferred instead of vmware-guestd
  - vmware-guestd will most probably be completely removed in the next release.
  - > vmtoolsd is not yet standard enabled in openSUSE packages.
- Obsolete merged patches vmxnet and vmxnet3.patch.
* Mon Mar  9 2009 mmarek@suse.cz
- renamed modprobe config to /etc/modprobe.d/50-vmnics.conf
  (required by new module-init-tools).
* Thu Feb 19 2009 dominique@leuenberger.net
- Upgrade to snapshot 2009.02.18
  * open-vm-tools now depend on glib 2.6.0 as a minimum requirement.
  * Added vmxnet module for Solaris, and reworked the HGFS module so it
    works without help from vmware-guestd.
  * Added implementation of new DnD protocol, which adds a dependency on
    a C++ compiler and the gtkmm library to vmware-user.
  * The code from the "core services" has been added to open-vm-tools,
    including a few tests. vmtoolsd + plugins are now capable of replacing
    vmware-guestd (vmware-user still needs to have some features ported
    over), but this code is still not to be considered as stable as the
    legacy services, so vmware-guestd is still included.
  * A few fixes for compatibility with non-GNU toolchains, newer Linux
    kernels and old gcc compilers.
- Added patch open-vm-tools-2009.02.18-vmxnet.patch
  Allows to compile kernelmodule vmxnet with kernels 2.6.29
  And open-vm-tools02009.02.18-vmxnet3.patch
* Mon Feb 16 2009 dominique@leuenberger.net
- Remove noDisplay=true from vmware-user.desktop, as KDE4
  does not autostart the app in this case. Fixes BNC #475627
* Thu Feb 12 2009 dominique@leuenberger.net
- Added vmware-user-autostart-wrapper to solve bnc #474076
  Using simple autostart technique, it can happen that the device
  at /proc/fs/vmblock/dev is not ready when vmware-user is started
  the autostart-wrapper takes this into account and tries for
  several times.
- Fix RPMLint warning with regarding wrong encoding of README file
* Wed Feb 11 2009 dominique@leuenberger.net
- Revert suid install of vmware-user-suid-wrapper, as rpmlint does
  not like it
  Instead we package /etc/permissions.d/open-vm-tools which sets
  the permission usig SuSEconfig.permissions
- Adjust the vmware-user.desktop file to actually launch
  vmware-user-suid-wrapper. Access to the vmblock requires su right.
  the suid-wrapper get's the file handle, drops the suid rights
  and launches vmware-user (with user privileges)
* Tue Feb 10 2009 prusnak@suse.cz
- install vmware-user-suid-wrapper with suid bit
* Mon Jan 26 2009 prusnak@suse.cz
- reviewed changes by Dominique
* Thu Jan 22 2009 dominique@leuenberger.net
- Update to version 2009.01.21
  * First open source release of the HGFS module for Solaris,
    under the CDDL. Other modules are expected to be added in
    the upcoming releases.
  * Added an implementation of vmblock on top of FUSE;
    vmware-user still  doesn't use this module even if it is
    available, though.
  * Linux modules now add the "supported" tag used by Novell in
    their SLES 10 SP2 release when loading modules.
  * Fix compilation of modules in newer Linux kernels which
    don't include $(LINUXINCLUDE) in the compiler flags anymore.
- Added Requires: kernel-%%1 to preamble, as rpmlint said it would
  be policy to require kenrel-$favour from the kmp
- marked config files in /etc as %%config (rpmlint)
* Fri Jan 16 2009 prusnak@suse.cz
- reviewed changes by Dominique
* Thu Dec 25 2008 dominique@leuenberger.net
- Update to version 2008.12.23
  * Lots of makefile cleanup with the switch to using libtool archives.
  * Automatically disable Unity if multimon support is disabled.
  * Actually build the pvscsi modules.
  * First bits of the "Core Service" project are starting to show up; the
    base "vmtools" library was added to the package. It currently is mostly
    a collection of the existing libraries already shipped with open-vm-tools,
    plus some extra functionality build on top of glib. Currently no other
    code in open-vm-tools uses it, so it's optional.
  * The HGFS driver was fixed for the Linux 2.6.28 kernel.
* Wed Nov 19 2008 dominique@leuenberger.net
- Updated to version 2008.11.19
  * The pvscsi Linux kernel module has been added (for kernels >= 2.6.8).
    It provides access to VMware's new paravirtualized SCSI device.
  * The HGFS driver and user-level code has seen a lot of refactoring to
    enable more consistent name escaping. The FreeBSD driver now supports
    symlinks.
  * The Linux module makefiles now support exporting symbol version files,
    allowing modules with dependencies (such as vsock, which depends on vmci)
    to correctly build and load on Linux >= 2.6.26 with CONFIG_MODVERSIONS.
  * Rudimentary support for dkms.
  * Assortment of bug fixes.
* Wed Oct 15 2008 dominique@leuenberger.net
- Updated to version 2008.10.10
  * The vmxnet3 Linux kernel module has been added. This module provides
    better network performance for the guest. The corresponding virtual
    hardware is available beginning with Workstation 6.5, though
    performance benefits are unlikely to be realized until a later VMware
    product release. The module should work for all kernels beginning with
    2.6.
  * The open-vm-tools no longer depend on libproc-dev. Several people
    reported this issue (Sourceforge bug 1960947).
  * Added a command line argument to skip privileged operations during
    make install (--without-root-privileges).
  * Guestd now supports backwards time synchronization, though the
    corresponding hypervisor-side changes are not yet part of any shipping
    VMware products.
  * Assortment of bug fixes.
* Wed Sep 17 2008 prusnak@suse.cz
- fixed license problem with region.c by applying patch from upstream
* Mon Sep  8 2008 dominique@leuenberger.net
- Removed patch kver.patch, refactored it's function in the
  make call, overriding the HEADER_DIR variable inside the
  Makefile (Tip sponsored by Adar from VMware Inc.)
* Thu Sep  4 2008 prusnak@suse.cz
- reviewed changes by Dominique
* Wed Sep  3 2008 dominique@leuenberger.net
- Activated compilation of modules vmci and vsock after fixing the
  kver.patch
- dropped obsoleted patch:
  * str_c.patch (included in update)
* Wed Sep  3 2008 prusnak@suse.cz
- updated to 2008-09-03
  * Fixed an issue where open-vm-tools fails to configure when using
  - -without-icu. Thanks to Timo Gurr for reporting the issue
    (Sourceforge bug 2046262).
  * Fixed failed build on Ubuntu Intrepid and Fedora 9.
    Thanks to Nathan Charles for reporting the issue
    (Sourceforge bug 2048423).
  * Fixed kernel module build issues on 2.6.27 pre-release kernels.
    Thanks to Dominique Leuenberger for reporting the issue
    (Sourceforge bug 2071170).
  * ...and other bug fixes.
- dropped obsoleted patches:
  * 2.6.27-kernel.patch (included in update)
  * fix-Werror.patch (included in update)
* Sun Aug 24 2008 dominique@leuenberger.net
- Added open-vm-tools-2008-08-08-2.6.27-kernel.patch to compile on
  more recent kernels (patch should be merged in next release)
* Fri Aug 22 2008 dominique@leuenberger.net
- added packageand(open-vm-tools:xorg-x11) to Supplements
  of open-vm-tools-gui sub package
* Fri Aug 22 2008 dominique@leuenberger.net
- Re-arranged comments for the configure line. Apparently, comments
  that appear in a line continuing on the next line, split using '\'
  break the flow
* Wed Aug 20 2008 dominique@leuenberger.net
- Added --without-kernel-modules to configure, as we take
  care of it on ourself using the loop, for the different
  kernel variants
* Tue Aug 12 2008 prusnak@suse.cz
- updated to 2008.08.08
  * Unity for X11 guests has been added. Unity is implemented within
    vmware-user and requires no additional setup beyond setting up the
    vmware-user application itself. Unity should work with Fusion 1.x
    releases as well as with the upcoming Workstation 6.5 release. Our
    in-house testing was with Linux guests, and they should mostly work.
    There is very little standing in the way of FreeBSD/Solaris support,
    though we've never built or tested Unity for those platforms.
  * The VMCI Linux kernel module has been added. This module provides
    high-speed datagram and socket interfaces for guest<->guest and
    host<->guest communication. It should work for all kernels beginning
    with 2.4, and for VMware products beginning with Workstation 6.5.
  * The VMCI sockets Linux kernel module has been added. It provides
    both datagram and stream socket interfaces to userlevel for use with
    VMCI. As with VMCI, it should work for kernels 2.4 or later, and for
    VMware products beginning with Workstation 6.5.
  * The command-line Toolbox has been added. This application provides
    the same functionality as the GTK Toolbox, but with a scriptable
    command-line interface. It also has some statistic retrieval commands
    that aren't found in the GTK Toolbox.
  * Fixed compilation of vmsync and vmmemctl Linux kernel modules on
    2.6.26. Thanks to Pavol Rusnak for the report (Sourceforge bug 2032683).
  * Fixed an issue with guestd's nicInfo updating mechanism. Thanks to
    Jason Lunz for the patch (not tracked on Sourceforge).
  * Fixed handling of $(DESTDIR) in automake. Thanks to Mike Auty for
    the patch (Sourceforge bug 2018802).
  * Fixed build of vmware-user using gtk 1.2. Thanks to Stephen Duncan
    for the report (Sourceforge bug 2014338).
  * Fixed compilation of lib/guestApp when using --without-x. Thanks to
    Martin Preishuber for the report (Sourceforge bug 2013568).
  * As usual, other bug fixes.
* Mon Jul 21 2008 prusnak@suse.cz
- updated to 2008.07.01:
  * fixed a backwards time synchronization issue
  * fixed an issue where open-vm-tools configured via --without-x didn't
    compile (not tracked on Sourceforge)
  * one can now pass --without-kernel-modules, --with-kernel-release, and
  - -with-linuxdir to the ./configure script
  * other bug fixes.
- branched open-vm-tools-gui subpackage with tools that need X
* Thu Jun 12 2008 prusnak@suse.cz
- open-vm-tools now requires vmware-kmp [bnc#397972]
- exclude AMD PCnet32 LANCE pci.id from Supplements list [bnc#397554]
* Mon Jun  9 2008 dominique-obs@leuenberger.net
- Updated to version 2008.06.03
  adopted spec file to new build structure layout (the binaries
  are now named correctly just after build and do not need to
  be renamed anymore)
- Replaced -werror patch with -fix-Werror-patch (submitted to
  VMware for inclusion)
* Mon Jun  2 2008 prusnak@suse.cz
- updated vmware init-script [bnc#394431]:
  * check whether /tmp/VMwareDnD exists and create it if necessary
  * use modules vmblock, vmmemctl, vmsync for better performance
  * mount the virtual system for Drag'n'Drop
* Wed May 28 2008 dominique-rpm@leuenberger.net
- Excluded the building of KMPs for XEN, probably nobody installs
  a vmware host in xen.
* Thu May 22 2008 prusnak@suse.cz
- added Recommends: open-vm-tools to KMP preamble [bnc#391434]
- added -y to %%fillup_and_insserv macro, so the service starts
  automatically [bnc#391434]
* Tue May 20 2008 dominique-rpm@leuenberger.net
- replaced %%build section with the one from openSUSE internal
  stable build, for building properly against all buildtargets
* Tue May 20 2008 dominique-rpm@leuenberger.net
- Added preamble for %%suse_kernel_module_package in order to have
  a Recommends: open-vm-tools on the kmp.
  The KMP is installed by Supplements: the hardware ID, and the KMP
  then pulls in the open-vm-tools package by Recommends (if available)
* Wed May  7 2008 dominique-rpm@leuenberger.net
- Updated to 2008.05.15:
  * Removed "blessed app" code for starting vmware-user
  * lib/file/filePosix.c: Use new Posix_RealPath implementation.
  * Cleanup UTF-8 handling.
* Wed May  7 2008 dominique-rpm@leuenberger.net
- Added patch open-vm-tools-2008.05.02-str.c that should solve
  compilation with FORTIFY_SOURCE enabled
* Tue May  6 2008 prusnak@suse.cz
- updated to 2008.05.02:
  * continued Unicode support
  * open-vm-tools now depends on libicu for codeset conversions
  * a few more bug fixes
* Mon Apr 28 2008 ro@suse.de
- tweak build section long enough to really build modules
  matching to kernel flavour (and not just build all for -default)
  (bnc#384192)
* Wed Apr 23 2008 ro@suse.de
- added vmware-KMP package and description tags to specfile
- added preable file for kmp packages
* Wed Apr 23 2008 prusnak@suse.cz
- fixed %%verifyscript
* Tue Apr 22 2008 prusnak@suse.cz
- updated to 2008.04.14
  * continued Unicode support
  * more bug fixes, including a security fix in guestd
- added permissions scripts to %%post section
* Tue Mar 25 2008 dominique-rpm@leuenberger.net
- updated to 2008.03.19
* Thu Mar 20 2008 prusnak@suse.cz
- add Supplements to automatically install in VMware
* Tue Mar 18 2008 prusnak@suse.cz
- first autobuild checkin
- turn off -Werror (werror.patch)
- reworked spec file
* Fri Mar 14 2008 dominique-rpm@leuenberger.net
- updated to 2008.03.11
  (developer snapshot to support all modules on 2.6.25 kernels)
* Tue Mar 11 2008 dominique-rpm@leuenberger.net
- updated to 2008.03.10
  (developer snapshot to support kernel version 2.6.25-rc1)
* Sun Mar  9 2008 dominique-rpm@leuenberger.net
- refactored open-vm-tools-kver.patch to detect the kernel source
  correctly
* Sat Mar  8 2008 dominique-rpm@leuenberger.net
- create link from /sbin/rcvmware to /etc/init.d/vmware-guest
- autostart the service after installation
* Sat Mar  8 2008 dominique-rpm@leuenberger.net
- initial build of open-vm-tools
- builds kmps and open-vm-tools
